@@ -598,16 +598,15 @@ class DebugBase(bdb.Bdb):
         #XXX - think of a better way to do this.  It's only a convience for
         #debugging the debugger - when the debugger code is in the current
         #directory.
-        if os.path.basename(fn) in [\
+        if os.path.basename(fn) in [
             'AsyncFile.py', 'AsyncIO.py',
-            'Config.py', 'DCTestResult.py',
+            'DebugConfig.py', 'DCTestResult.py',
             'DebugBase.py', 'DebugClientBase.py', 
             'DebugClientCapabilities.py', 'DebugClient.py', 
             'DebugClientThreads.py', 'DebugProtocol.py',
             'DebugThread.py', 'FlexCompleter.py',
-            'PyCoverage.py', 'PyProfile.py',
-            'Cyclops.py', 'HTMLCycclops.py', 'RunCyclops.py',
-        ]:
+            'PyCoverage.py', 'PyProfile.py'] or \
+           os.path.dirname(fn).endswith("Cyclops"):
             return 1
 
         if self._dbgClient.shouldSkip(fn):
