@@ -17,6 +17,7 @@ import atexit
 import time
 import imp
 import re
+import distutils.sysconfig
 
 
 from DebugProtocol import *
@@ -156,13 +157,10 @@ class DebugClientBase(object):
         self.readstream = None
         self.writestream = None
         self.errorstream = None
+        self.pollingDisabled = False
+        
+        self.skipdirs = sys.path[:]
         
-        # So much for portability.
-        if sys.platform == 'win32':
-            self.skipdir = sys.prefix
-        else:
-            self.skipdir = os.path.join(sys.prefix,'lib/python' + sys.version[0:3])
-            
         self.variant = 'You should not see this'
         
         # commandline completion stuff
@@ -242,7 +240,7 @@ class DebugClientBase(object):
         """
         self.write("%s%s\n" % (ResponseRaw, unicode((prompt, echo))))
         self.inRawMode = 1
-        self.eventLoop()
+        self.eventLoop(True)
         return self.rawLine
 
     def input(self,prompt):
@@ -443,6 +441,7 @@ class DebugClientBase(object):
                 self.debugMod.__dict__['__file__'] = sys.argv[0]
                 sys.modules['__main__'] = self.debugMod
                 execfile(sys.argv[0], self.debugMod.__dict__)
+                self.writestream.flush()
                 return
 
             if cmd == RequestCoverage:
@@ -486,6 +485,7 @@ class DebugClientBase(object):
                 self.debugMod.__dict__['__file__'] = sys.argv[0]
                 execfile(sys.argv[0], self.debugMod.__dict__)
                 self.cover.save()
+                self.writestream.flush()
                 return
 
             if cmd == RequestProfile:
@@ -519,6 +519,7 @@ class DebugClientBase(object):
                 sys.modules['__main__'] = self.debugMod
                 self.prof.run('execfile(' + `sys.argv[0]` + ')')
                 self.prof.save()
+                self.writestream.flush()
                 return
 
             if cmd == RequestCyclops:
@@ -545,6 +546,7 @@ class DebugClientBase(object):
                 
                 sys.modules['__main__'] = self.debugMod
                 RunCyclops.run(fn, modfunc, int(reports), self)
+                self.writestream.flush()
                 return
 
             if cmd == RequestShutdown:
@@ -896,11 +898,15 @@ class DebugClientBase(object):
             # At this point simulate an event loop.
             self.eventLoop()
 
-    def eventLoop(self):
+    def eventLoop(self, disablePolling = False):
         """
         Public method implementing our event loop.
+        
+        @param disablePolling flag indicating to enter an event loop with
+            polling disabled (boolean)
         """
         self.eventExit = None
+        self.pollingDisabled = disablePolling
 
         while self.eventExit is None:
             wrdy = []
@@ -927,11 +933,15 @@ class DebugClientBase(object):
                 self.writeReady(self.errorstream.fileno())
 
         self.eventExit = None
+        self.pollingDisabled = False
 
     def eventPoll(self):
         """
         Public method to poll for events like 'set break point'.
         """
+        if self.pollingDisabled:
+            return
+        
         # the choice of a ~0.5 second poll interval is arbitrary.
         lasteventpolltime = getattr(self, 'lasteventpolltime', time.time())
         now = time.time()
@@ -948,7 +958,7 @@ class DebugClientBase(object):
         if AsyncPendingWrite(self.errorstream):
             wrdy.append(self.errorstream)
         
-        # imdediate return if nothing is ready.
+        # immediate return if nothing is ready.
         try:
             rrdy, wrdy, xrdy = select.select([self.readstream],wrdy,[],0)
         except select.error:
@@ -1061,9 +1071,10 @@ class DebugClientBase(object):
             
         # Eliminate anything that is part of the Python installation.
         afn = self.absPath(fn)
-        if afn.find(self.skipdir) == 0:
-            return 1
-            
+        for d in self.skipdirs:
+            if afn.startswith(d):
+                return 1
+        
         return 0
         
     def getRunning(self):
