@@ -31,17 +31,10 @@ class PyProfile(profile.Profile):
         """
         try:
             profile.Profile.__init__(self, timer, bias)
-        except ArgumentError:
+        except TypeError:
             profile.Profile.__init__(self, timer)
         
-        self.dispatch = {
-            "call": profile.Profile.trace_dispatch_call,
-            "exception": profile.Profile.trace_dispatch_exception,
-            "return": profile.Profile.trace_dispatch_return,
-            "c_call": profile.Profile.trace_dispatch_c_call,
-            "c_exception": profile.Profile.trace_dispatch_exception,
-            "c_return": profile.Profile.trace_dispatch_return,
-            }
+        self.dispatch = self.__class__.dispatch
         
         basename = os.path.splitext(basename)[0]
         self.profileCache = "%s.profile" % basename
@@ -142,9 +135,12 @@ class PyProfile(profile.Profile):
         else:
             timings[fn] = 0, 0, 0, 0, {}
         return 1
-        
+    
     dispatch = {
         "call": trace_dispatch_call,
         "exception": profile.Profile.trace_dispatch_exception,
         "return": profile.Profile.trace_dispatch_return,
+        "c_call": profile.Profile.trace_dispatch_c_call,
+        "c_exception": profile.Profile.trace_dispatch_return,  # the C function returned
+        "c_return": profile.Profile.trace_dispatch_return,
         }
