@@ -302,7 +302,7 @@ it trys to execute the lines accumulated so far.
                     Dir.chdir(wd)
                 end
                 @running = fn
-                command = "$0 = ''; $0 << '%s'; require '%s'" % [fn, fn]
+                command = "$0 = '%s'; require '%s'" % [fn, fn]
                 set_trace_func proc { |event, file, line, id, binding_, klass, *rest|
                     DEBUGGER__.context.trace_func(event, file, line, id, binding_, klass)
                 }
@@ -329,7 +329,7 @@ it trys to execute the lines accumulated so far.
                 else
                     Dir.chdir(wd)
                 end
-                command = "$0 = ''; $0 << '%s'; require '%s'" % [fn, fn]
+                command = "$0 = '%s'; require '%s'" % [fn, fn]
                 @frames = []
                 set_trace_func proc { |event, file, line, id, binding_, klass, *rest|
                     trace_func(event, file, line, id, binding_, klass)
@@ -1069,7 +1069,7 @@ Method used to start the remote debugger.
         write("%s%s|%d\n" % [PassiveStartup, @running, exceptions ? 1 : 0])
         interact()
         
-        command = "$0 = ''; $0 << '%s'; require '%s'" % [fn, fn]
+        command = "$0 = '%s'; require '%s'" % [fn, fn]
         set_trace_func proc { |event, file, line, id, binding_, klass, *rest|
             DEBUGGER__.context.trace_func(event, file, line, id, binding_, klass)
         }
