@@ -1,14 +1,16 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 =begin edoc
 File defining the debug clients capabilities.
 =end
 
-$KCODE = 'UTF8'
-require 'jcode'
+if RUBY_VERSION < "1.9"
+    $KCODE = 'UTF8'
+    require 'jcode'
+end
 
 HasDebugger      = 0x0001
 HasInterpreter   = 0x0002
