@@ -64,7 +64,7 @@ class DebugServer(QTcpServer):
             a syntax error in a breakpoint condition
     @signal clientClearWatch(condition) emitted after the debug client
             has decided to clear a temporary watch expression
-    @signal clientWatchConditionError(fn, lineno) emitted after the client has signaled
+    @signal clientWatchConditionError(condition) emitted after the client has signaled
             a syntax error in a watch expression
     @signal clientRawInput(prompt, echo) emitted after a raw input request was received
     @signal clientBanner(banner) emitted after the client banner was received
@@ -436,7 +436,7 @@ class DebugServer(QTcpServer):
         if self.debugging:
             cond, special = self.__splitWatchCondition(condition)
             index = self.watchpointModel.getWatchPointIndex(cond, special)
-            self.watchpoint.deleteWatchPointByIndex(index)
+            self.watchpointModel.deleteWatchPointByIndex(index)
         
     def __deleteWatchPoints(self, parentIndex, start, end):
         """
@@ -1048,23 +1048,21 @@ class DebugServer(QTcpServer):
         """
         self.emit(SIGNAL('clientBreakConditionError'), filename, lineno)
         
-    def clientClearWatch(self, filename, lineno):
+    def clientClearWatch(self, condition):
         """
-        Public method to process the client clear watch expression command.
+        Public slot to handle the clientClearWatch signal.
         
-        @param filename filename of the watch expression (string)
-        @param lineno line umber of the watch expression (integer)
+        @param condition expression of watch expression to clear (string or QString)
         """
-        self.emit(SIGNAL('clientClearWatch'), filename, lineno)
+        self.emit(SIGNAL('clientClearWatch'), condition)
         
-    def clientWatchConditionError(self, filename, lineno):
+    def clientWatchConditionError(self, condition):
         """
         Public method to process the client watch expression error info.
         
-        @param filename filename of the watch expression (string)
-        @param lineno line umber of the watch expression (integer)
+        @param condition expression of watch expression to clear (string or QString)
         """
-        self.emit(SIGNAL('clientWatchConditionError'), filename, lineno)
+        self.emit(SIGNAL('clientWatchConditionError'), condition)
         
     def clientRawInput(self, prompt, echo):
         """
