@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -181,6 +181,7 @@ class DebuggerInterfaceNone(QObject):
         @param stmt the Python statement to execute (string). It
               should not have a trailing newline.
         """
+        self.debugServer.clientStatement(False)
         return
 
     def remoteStep(self):
@@ -239,39 +240,39 @@ class DebuggerInterfaceNone(QObject):
         
     def remoteBreakpointIgnore(self, fn, line, count):
         """
-        Public method to ignore a breakpoint the next couple of occurences.
+        Public method to ignore a breakpoint the next couple of occurrences.
         
         @param fn filename the breakpoint belongs to (string)
         @param line linenumber of the breakpoint (int)
-        @param count number of occurences to ignore (int)
+        @param count number of occurrences to ignore (int)
         """
         return
         
     def remoteWatchpoint(self, cond, set, temp = False):
         """
-        Public method to set or clear a watchpoint.
+        Public method to set or clear a watch expression.
         
-        @param cond condition of the watchpoint (string)
-        @param set flag indicating setting or resetting a watchpoint (boolean)
-        @param temp flag indicating a temporary watchpoint (boolean)
+        @param cond expression of the watch expression (string)
+        @param set flag indicating setting or resetting a watch expression (boolean)
+        @param temp flag indicating a temporary watch expression (boolean)
         """
         return
     
     def remoteWatchpointEnable(self, cond, enable):
         """
-        Public method to enable or disable a watchpoint.
+        Public method to enable or disable a watch expression.
         
-        @param cond condition of the watchpoint (string)
-        @param enable flag indicating enabling or disabling a watchpoint (boolean)
+        @param cond expression of the watch expression (string)
+        @param enable flag indicating enabling or disabling a watch expression (boolean)
         """
         return
     
     def remoteWatchpointIgnore(self, cond, count):
         """
-        Public method to ignore a watchpoint the next couple of occurences.
+        Public method to ignore a watch expression the next couple of occurrences.
         
-        @param cond condition of the watchpoint (string)
-        @param count number of occurences to ignore (int)
+        @param cond expression of the watch expression (string)
+        @param count number of occurrences to ignore (int)
         """
         return
     
@@ -333,6 +334,7 @@ class DebuggerInterfaceNone(QObject):
         """
         Public slot to get the banner info of the remote client.
         """
+        self.debugServer.clientBanner("No backend", "", "")
         return
         
     def remoteCapabilities(self):
