@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -57,7 +57,7 @@ class DebuggerInterfaceRuby(QObject):
         QObject.__init__(self)
         
         self.__isNetworked = True
-        self.__autoContinue = True
+        self.__autoContinue = not passive
         
         self.debugServer = debugServer
         self.passive = passive
@@ -68,7 +68,7 @@ class DebuggerInterfaceRuby(QObject):
         # set default values for capabilities of clients
         self.clientCapabilities = ClientDefaultCapabilities
         
-        self.codec = QTextCodec.codecForName(sys.getdefaultencoding())
+        self.codec = QTextCodec.codecForName(str(Preferences.getSystem("StringEncoding")))
         
         if passive:
             # set translation function
@@ -147,7 +147,7 @@ class DebuggerInterfaceRuby(QObject):
         redirect = str(Preferences.getDebugger("RubyRedirect"))
         
         if Preferences.getDebugger("RemoteDbgEnabled"):
-            ipaddr = socket.gethostbyname(socket.gethostname())
+            ipaddr = self.debugServer.getHostAddress(False)[0]
             rexec = unicode(Preferences.getDebugger("RemoteExecution"))
             rhost = unicode(Preferences.getDebugger("RemoteHost"))
             if rhost == "":
@@ -194,12 +194,13 @@ class DebuggerInterfaceRuby(QObject):
             except UnpackError:
                 pass
         
+        ipaddr = self.debugServer.getHostAddress(True)
         if Preferences.getDebugger("ConsoleDbgEnabled"):
             ccmd = unicode(Preferences.getDebugger("ConsoleDbgCommand"))
             if ccmd:
                 args = Utilities.parseOptionString(ccmd) + \
                        [interpreter, os.path.abspath(debugClient),
-                        str(port), '0']
+                        str(port), '0', ipaddr]
                 args[0] = Utilities.getExecutablePath(args[0])
                 process = self.__startProcess(args[0], args[1:], clientEnv)
                 if process is None:
@@ -210,7 +211,7 @@ class DebuggerInterfaceRuby(QObject):
                 return process, self.__isNetworked
         
         process = self.__startProcess(interpreter, 
-            [debugClient, str(port), redirect], 
+            [debugClient, str(port), redirect, ipaddr], 
             clientEnv)
         if process is None:
             KQMessageBox.critical(None,
@@ -237,7 +238,7 @@ class DebuggerInterfaceRuby(QObject):
         redirect = str(project.getDebugProperty("REDIRECT"))
         
         if project.getDebugProperty("REMOTEDEBUGGER"):
-            ipaddr = socket.gethostbyname(socket.gethostname())
+            ipaddr = self.debugServer.getHostAddress(False)[0]
             rexec = project.getDebugProperty("REMOTECOMMAND")
             rhost = project.getDebugProperty("REMOTEHOST")
             if rhost == "":
@@ -281,12 +282,13 @@ class DebuggerInterfaceRuby(QObject):
             except UnpackError:
                 pass
         
+        ipaddr = self.debugServer.getHostAddress(True)
         if project.getDebugProperty("CONSOLEDEBUGGER"):
             ccmd = unicode(project.getDebugProperty("CONSOLECOMMAND"))
             if ccmd:
                 args = Utilities.parseOptionString(ccmd) + \
                        [interpreter, os.path.abspath(debugClient),
-                        str(port), '0']
+                        str(port), '0', ipaddr]
                 args[0] = Utilities.getExecutablePath(args[0])
                 process = self.__startProcess(args[0], args[1:], clientEnv)
                 if process is None:
@@ -297,7 +299,7 @@ class DebuggerInterfaceRuby(QObject):
                 return process, self.__isNetworked
         
         process = self.__startProcess(interpreter, 
-            [debugClient, str(port), redirect], 
+            [debugClient, str(port), redirect, ipaddr], 
             clientEnv)
         if process is None:
             KQMessageBox.critical(None,
@@ -525,44 +527,44 @@ class DebuggerInterfaceRuby(QObject):
         
     def remoteBreakpointIgnore(self, fn, line, count):
         """
-        Public method to ignore a breakpoint the next couple of occurences.
+        Public method to ignore a breakpoint the next couple of occurrences.
         
         @param fn filename the breakpoint belongs to (string)
         @param line linenumber of the breakpoint (int)
-        @param count number of occurences to ignore (int)
+        @param count number of occurrences to ignore (int)
         """
         fn = self.translate(fn, False)
         self.__sendCommand('%s%s,%d,%d\n' % (RequestBreakIgnore, fn, line, count))
         
     def remoteWatchpoint(self, cond, set, temp = False):
         """
-        Public method to set or clear a watchpoint.
+        Public method to set or clear a watch expression.
         
-        @param cond condition of the watchpoint (string)
-        @param set flag indicating setting or resetting a watchpoint (boolean)
-        @param temp flag indicating a temporary watchpoint (boolean)
+        @param cond expression of the watch expression (string)
+        @param set flag indicating setting or resetting a watch expression (boolean)
+        @param temp flag indicating a temporary watch expression (boolean)
         """
-        # cond is combination of cond and special (s. watchpoint viewer)
+        # cond is combination of cond and special (s. watch expression viewer)
         self.__sendCommand('%s%s@@%d@@%d\n' % (RequestWatch, cond, temp, set))
     
     def remoteWatchpointEnable(self, cond, enable):
         """
-        Public method to enable or disable a watchpoint.
+        Public method to enable or disable a watch expression.
         
-        @param cond condition of the watchpoint (string)
-        @param enable flag indicating enabling or disabling a watchpoint (boolean)
+        @param cond expression of the watch expression (string)
+        @param enable flag indicating enabling or disabling a watch expression (boolean)
         """
-        # cond is combination of cond and special (s. watchpoint viewer)
+        # cond is combination of cond and special (s. watch expression viewer)
         self.__sendCommand('%s%s,%d\n' % (RequestWatchEnable, cond, enable))
     
     def remoteWatchpointIgnore(self, cond, count):
         """
-        Public method to ignore a watchpoint the next couple of occurences.
+        Public method to ignore a watch expression the next couple of occurrences.
         
-        @param cond condition of the watchpoint (string)
-        @param count number of occurences to ignore (int)
+        @param cond expression of the watch expression (string)
+        @param count number of occurrences to ignore (int)
         """
-        # cond is combination of cond and special (s. watchpoint viewer)
+        # cond is combination of cond and special (s. watch expression viewer)
         self.__sendCommand('%s%s,%d\n' % (RequestWatchIgnore, cond, count))
     
     def remoteRawInput(self,s):
