@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -16,11 +16,12 @@ class ExceptionsFilterDialog(QDialog, Ui_ExceptionsFilterDialog):
     """
     Class implementing the exceptions filter dialog.
     """
-    def __init__(self, excList, parent=None):
+    def __init__(self, excList, ignore, parent=None):
         """
         Constructor
         
         @param excList list of exceptions to be edited (QStringList)
+        @param ignore flag indicating the ignore exceptions mode (boolean)
         @param parent the parent widget (QWidget)
         """
         QDialog.__init__(self, parent)
@@ -29,8 +30,19 @@ class ExceptionsFilterDialog(QDialog, Ui_ExceptionsFilterDialog):
         
         self.exceptionList.addItems(excList)
         
-        self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
+        if ignore:
+            self.setWindowTitle(self.trUtf8("Ignored Exceptions"))
+            self.exceptionList.setToolTip(self.trUtf8("List of ignored exceptions"))
         
+        self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
+    
+    @pyqtSignature("")
+    def on_exceptionList_itemSelectionChanged(self):
+        """
+        Private slot to handle the change of the selection.
+        """
+        self.deleteButton.setEnabled(len(self.exceptionList.selectedItems()) > 0)
+    
     @pyqtSignature("")
     def on_deleteButton_clicked(self):
         """
@@ -38,6 +50,15 @@ class ExceptionsFilterDialog(QDialog, Ui_ExceptionsFilterDialog):
         """
         itm = self.exceptionList.takeItem(self.exceptionList.currentRow())
         del itm
+    
+    @pyqtSignature("")
+    def on_deleteAllButton_clicked(self):
+        """
+        Private slot to delete all exceptions of the listbox.
+        """
+        while self.exceptionList.count() > 0:
+            itm = self.exceptionList.takeItem(0)
+            del itm
 
     @pyqtSignature("")
     def on_addButton_clicked(self):
