@@ -114,10 +114,7 @@ class APIGenerator(object):
             self.api.append('%s%s?%d(%s)' % \
                 (self.moduleName, _class.name, id, 
                  ', '.join(_class.methods['__init__'].parameters[1:])))
-            self.api.append('%s%s.__init__?%d(%s)' % \
-                (self.moduleName, _class.name, id, 
-                 ', '.join(_class.methods['__init__'].parameters)))
-            
+        
         if self.newStyle:
             classNameStr = "%s%s." % (self.moduleName, className)
         else:
