@@ -873,7 +873,9 @@ class ModuleDocument(object):
                                    or m.group("SignalName2")
                     signalDesc = 1 and m.group("SignalDescription1") \
                                    or m.group("SignalDescription2")
-                    signalDict[signalName] = [signalDesc]
+                    signalDict[signalName] = []
+                    if signalDesc is not None:
+                        signalDict[signalName].append(signalDesc)
                     lastItem = signalDict[signalName]
                 elif desc.startswith("@event"):
                     inTagSection = True
@@ -884,7 +886,9 @@ class ModuleDocument(object):
                                    or m.group("EventName2")
                     eventDesc = 1 and m.group("EventDescription1") \
                                    or m.group("EventDescription2")
-                    eventDict[eventName] = [eventDesc]
+                    eventDict[eventName] = []
+                    if eventDesc is not None:
+                        eventDict[eventName].append(eventDesc)
                     lastItem = eventDict[eventName]
                 elif desc.startswith("@deprecated"):
                     inTagSection = True
