@@ -7,6 +7,8 @@
 Module defining common data to be used by all modules.
 """
 
+import sys
+
 # names of the various settings objects
 settingsNameOrganization = "Eric4"
 settingsNameGlobal = "eric4"
@@ -16,3 +18,11 @@ settingsNameRecent = "eric4recent"
 recentNameMultiProject = "MultiProjects"
 recentNameProject = "Projects"
 recentNameFiles = "Files"
+
+def isWindowsPlatform():
+    """
+    Function to check, if this is a Windows platform.
+    
+    @return flag indicating Windows platform (boolean)
+    """
+    return sys.platform.startswith("win")
