@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -257,7 +257,7 @@ class PackageDiagram(UMLDialog):
         """
         meths = _class.methods.keys()
         meths.sort()
-        attrs = _class.attributes[:]
+        attrs = _class.attributes.keys()
         attrs.sort()
         name = _class.name
         if isRbModule:
@@ -292,8 +292,8 @@ class PackageDiagram(UMLDialog):
                 assoc = AssociationItem(\
                         self.__getCurrentShape(route[1]),
                         self.__getCurrentShape(route[0]),
-                        Generalisation,
-                        scene = self.scene)
+                        Generalisation)
+                self.scene.addItem(assoc)
         
     def show(self):
         """
