@@ -144,7 +144,7 @@ class HelpBrowser(QWebView):
                         """ for file <b>%1</b>.</p>""").arg(name.path()))
                 return
         
-        self.setUrl(name)
+        self.load(name)
         if self.__homeUrl is None:
             self.__homeUrl = name
     
@@ -423,7 +423,7 @@ class HelpBrowser(QWebView):
             if ok and size == 0:
                 return
             
-            dlg = DownloadDialog(reply, False, self.page())
+            dlg = DownloadDialog(reply, True, self.page())
             self.connect(dlg, SIGNAL("done()"), self.__downloadDone)
             self.__downloadWindows.append(dlg)
             dlg.show()
@@ -443,7 +443,9 @@ class HelpBrowser(QWebView):
         """
         dlg = self.sender()
         if dlg in self.__downloadWindows:
+            self.disconnect(dlg, SIGNAL("done()"), self.__downloadDone)
             self.__downloadWindows.remove(dlg)
+            dlg.deleteLater()
     
     def __downloadRequested(self, request):
         """
