@@ -809,14 +809,13 @@ class HelpWindow(KQMainWindow):
         """
         if webkit:
             url = QUrl(self.pathCombo.currentText())
-            if not url.isEmpty():
-                le = self.pathCombo.lineEdit()
-                p = le.palette()
-                if url.scheme() == "https":
-                    p.setBrush(QPalette.Base, QBrush(Preferences.getHelp("SaveUrlColor")))
-                else:
-                    p.setBrush(QPalette.Base, self.pathComboDefaultColor)
-                le.setPalette(p)
+            le = self.pathCombo.lineEdit()
+            p = le.palette()
+            if url.isEmpty() or url.scheme() != "https":
+                p.setBrush(QPalette.Base, self.pathComboDefaultColor)
+            else:
+                p.setBrush(QPalette.Base, QBrush(Preferences.getHelp("SaveUrlColor")))
+            le.setPalette(p)
     
     def __elide(self, txt, mode = Qt.ElideRight, length = 40):
         """
@@ -1154,6 +1153,10 @@ class HelpWindow(KQMainWindow):
             del self.__class__.helpwindows[self.__class__.helpwindows.index(self)]
         except ValueError:
             pass
+        
+        if not self.fromEric:
+            Preferences.syncPreferences()
+        
         e.accept()
         self.emit(SIGNAL("helpClosed"))
 
@@ -1288,7 +1291,8 @@ class HelpWindow(KQMainWindow):
                 self.__setPathComboBackground()
                 
                 self.printAct.setEnabled(hasattr(cb, 'print_'))
-                self.printPreviewAct.setEnabled(hasattr(cb, 'print_'))
+                if self.printPreviewAct:
+                    self.printPreviewAct.setEnabled(hasattr(cb, 'print_'))
                 
                 if webkit:
                     self.iconChanged(cb.icon())
@@ -1305,7 +1309,7 @@ class HelpWindow(KQMainWindow):
         self.rightMenuAct.setEnabled(index < self.tabWidget.count() - 1)
         self.tabContextCloseAct.setEnabled(self.tabWidget.count() > 1)
         
-        coord = self.mapToGlobal(coord)
+        coord = self.tabWidget.mapToGlobal(coord)
         self.__tabContextMenu.popup(coord)
     
     def __tabContextMenuMoveLeft(self):
