@@ -1,42 +1,29 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Compatibility module to use the KDE Printer instead of the Qt Printer.
 """
 
-import os
+import sys
+
+from PyQt4.QtGui import QPrinter
 
 import Preferences
 
-try:
-    raise ImportError
-    # TODO: KDE 4
-##    from qt import QPrinter
-##    from kdeprint import KPrinter
-##    class KQPrinter(KPrinter):
-##        """
-##        Compatibility class to use the KDE Printer instead of the Qt Printer.
-##        """
-##        ScreenResolution = QPrinter.ScreenResolution
-##        PrinterResolution = QPrinter.PrinterResolution
-##        HighResolution = QPrinter.HighResolution
-##        Compatible = QPrinter.Compatible
+class __kdeKQPrinter(QPrinter):
+    """
+    Compatibility class to use the Qt Printer.
+    """
+    pass
 
-except (ImportError, RuntimeError):
-    os.environ["e4nokde"] = "1"
-
-from PyQt4.QtGui import QPrinter
 class __qtKQPrinter(QPrinter):
     """
     Compatibility class to use the Qt Printer.
     """
     pass
-    # TODO: KDE 4
-    # add the method setup() opening a print dialog, returns true if OK was pressed
-    # def setup(self, parent = None, caption = QString()):
 
 ################################################################################
 
@@ -47,7 +34,7 @@ def KQPrinter(mode = QPrinter.ScreenResolution):
     @param mode printer mode (QPrinter.PrinterMode)
     @return reference to the printer object
     """
-    if Preferences.getUI("UseKDEDialogs") and not os.getenv("e4nokde"):
+    if Preferences.getUI("UseKDEDialogs") and not sys.e4nokde:
         return __kdeKQPrinter(mode)
     else:
         return __qtKQPrinter(mode)
