@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 
@@ -32,6 +32,11 @@ class PluginInfoDialog(QDialog, Ui_PluginInfoDialog):
         
         self.pm = pluginManager
         
+        self.__autoActivateColumn = 3
+        self.__activeColumn = 4
+        
+        self.pluginList.headerItem().setText(self.pluginList.columnCount(), "")
+        
         # populate the list
         self.__populateList()
         self.pluginList.sortByColumn(0, Qt.AscendingOrder)
@@ -66,16 +71,17 @@ class PluginInfoDialog(QDialog, Ui_PluginInfoDialog):
         infoList = QStringList() \
             << info[0] \
             << info[1] \
-            << (info[2] and self.trUtf8("Yes") or self.trUtf8("No")) \
+            << info[2] \
             << (info[3] and self.trUtf8("Yes") or self.trUtf8("No")) \
-            << info[4]
+            << (info[4] and self.trUtf8("Yes") or self.trUtf8("No")) \
+            << info[5]
         itm = QTreeWidgetItem(self.pluginList, infoList)
-        if info[5]:
+        if info[6]:
             # plugin error
-            for col in range(5):
+            for col in range(self.pluginList.columnCount()):
                 itm.setForeground(col, QBrush(Qt.red))
-        itm.setTextAlignment(2, Qt.AlignHCenter)
-        itm.setTextAlignment(3, Qt.AlignHCenter)
+        itm.setTextAlignment(self.__autoActivateColumn, Qt.AlignHCenter)
+        itm.setTextAlignment(self.__activeColumn, Qt.AlignHCenter)
         
         self.pluginList.header().resizeSections(QHeaderView.ResizeToContents)
         self.pluginList.header().setStretchLastSection(True)
@@ -88,8 +94,8 @@ class PluginInfoDialog(QDialog, Ui_PluginInfoDialog):
         """
         itm = self.pluginList.itemAt(coord)
         if itm is not None:
-            autoactivate = itm.text(2) == self.trUtf8("Yes")
-            if itm.text(3) == self.trUtf8("Yes"):
+            autoactivate = itm.text(self.__autoActivateColumn) == self.trUtf8("Yes")
+            if itm.text(self.__activeColumn) == self.trUtf8("Yes"):
                 self.__activateAct.setEnabled(False)
                 self.__deactivateAct.setEnabled(autoactivate)
             else:
