@@ -503,8 +503,16 @@ class PluginInstallDialog(QDialog):
         @param parent reference to the parent widget (QWidget)
         """
         QDialog.__init__(self, parent)
+        self.setSizeGripEnabled(True)
+        
+        self.__layout = QVBoxLayout(self)
+        self.__layout.setMargin(0)
+        self.setLayout(self.__layout)
         
         self.cw = PluginInstallWidget(pluginManager, pluginFileNames, self)
+        size = self.cw.size()
+        self.__layout.addWidget(self.cw)
+        self.resize(size)
         
         self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.accept)
         self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.reject)
