@@ -418,7 +418,7 @@ class PluginManager(QObject):
             savedInactiveList = ial.toStringList()
         else:
             savedInactiveList = None
-        if self.__develPluginName is not None:
+        if self.__develPluginName is not None and savedInactiveList is not None:
             savedInactiveList.removeAll(self.__develPluginName)
         names = self.__inactiveModules.keys()
         names.sort()
@@ -723,7 +723,12 @@ class PluginManager(QObject):
                getattr(module, "error", QString("")).isEmpty():
                 plugin_name = getattr(module, "pluginTypename")
                 if hasattr(module, "displayString"):
-                    pluginDict[plugin_name] = getattr(module, "displayString")
+                    try:
+                        disp = module.displayString()
+                    except TypeError:
+                        disp = getattr(module, "displayString")
+                    if disp != "":
+                        pluginDict[plugin_name] = disp
                 else:
                     pluginDict[plugin_name] = QString(plugin_name)
         
