@@ -598,8 +598,16 @@ class PluginRepositoryDialog(QDialog):
         @param parent reference to the parent widget (QWidget)
         """
         QDialog.__init__(self, parent)
+        self.setSizeGripEnabled(True)
+        
+        self.__layout = QVBoxLayout(self)
+        self.__layout.setMargin(0)
+        self.setLayout(self.__layout)
         
         self.cw = PluginRepositoryWidget(self)
+        size = self.cw.size()
+        self.__layout.addWidget(self.cw)
+        self.resize(size)
         
         self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.accept)
         self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.reject)
@@ -659,4 +667,4 @@ class PluginRepositoryWindow(KQMainWindow):
                 ).arg(applPath),
                 self.trUtf8('OK'))
         
-        self.close()
\ No newline at end of file
+        self.close()
