@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -27,7 +27,7 @@ name = "Ericapi Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "4.1.0"
+version = "4.3.0"
 className = "EricapiPlugin"
 packageName = "__core__"
 shortDescription = "Show the Ericapi dialogs."
@@ -98,10 +98,9 @@ class EricapiPlugin(QObject):
                 """<b>Generate API file</b>"""
                 """<p>Generate an API file using eric4-api.</p>"""
             ))
-            self.__projectAct.connectIt(SIGNAL('triggered()'),
-                self.__doEricapi)
+            self.connect(self.__projectAct, SIGNAL('triggered()'), self.__doEricapi)
             e4App().getObject("Project").addE4Actions([self.__projectAct])
-            self.__projectAct.addTo(menu)
+            menu.addAction(self.__projectAct)
         
         self.connect(e4App().getObject("Project"), SIGNAL("showMenu"), 
                      self.__projectShowMenu)
@@ -141,7 +140,7 @@ class EricapiPlugin(QObject):
         """
         project = e4App().getObject("Project")
         parms = project.getData('DOCUMENTATIONPARMS', "ERIC4API")
-        dlg = EricapiConfigDialog(project.getProjectPath(), parms)
+        dlg = EricapiConfigDialog(project, parms)
         if dlg.exec_() == QDialog.Accepted:
             args, parms = dlg.generateParameters()
             project.setData('DOCUMENTATIONPARMS', "ERIC4API", parms)
@@ -152,11 +151,21 @@ class EricapiPlugin(QObject):
             if res:
                 dia.exec_()
                 
-            outfile = parms['outputFile']
+            outputFileName = parms['outputFile']
                 
-            # add it to the project data, if it isn't in already
-            outfile = outfile.replace(project.ppath+os.sep, '')
-            if outfile not in project.pdata['OTHERS']:
-                project.pdata['OTHERS'].append(outfile)
-                project.setDirty(True)
-                project.othersAdded(outfile)
+            # add output files to the project data, if they aren't in already
+            for progLanguage in parms['languages']:
+                if "%L" in outputFileName:
+                    outfile = outputFileName.replace("%L", progLanguage)
+                else:
+                    if len(progLanguages) == 1:
+                        outfile = outputFileName
+                    else:
+                        root, ext = os.path.splitext(outputFileName)
+                        outfile = "%s-%s%s" % (root, progLanguage.lower(), ext)
+                
+                outfile = outfile.replace(project.ppath+os.sep, '')
+                if outfile not in project.pdata['OTHERS']:
+                    project.pdata['OTHERS'].append(outfile)
+                    project.setDirty(True)
+                    project.othersAdded(outfile)
