@@ -27,7 +27,6 @@ deactivateable = True
 version = "4.3.0"
 pluginType = "version_control"
 pluginTypename = "PySvn"
-displayString = QApplication.translate('VcsPySvnPlugin', 'Subversion (pysvn)')
 className = "VcsPySvnPlugin"
 packageName = "__core__"
 shortDescription = "Implements the PySvn version control interface."
@@ -69,16 +68,28 @@ def getVcsSystemIndicator():
     @return dictionary with indicator as key and a tuple with the vcs name (string)
         and vcs display string (QString)
     """
-    global displayString, pluginTypename
+    global pluginTypename
     data = {}
     try:
         import pysvn
-        data[".svn"] = (pluginTypename, displayString)
-        data["_svn"] = (pluginTypename, displayString)
+        data[".svn"] = (pluginTypename, displayString())
+        data["_svn"] = (pluginTypename, displayString())
     except ImportError:
         pass
     return data
 
+def displayString():
+    """
+    Public function to get the display string.
+    
+    @return display string (QString)
+    """
+    try:
+        import pysvn
+        return QApplication.translate('VcsPySvnPlugin', 'Subversion (pysvn)')
+    except ImportError:
+        return QString()
+
 subversionCfgPluginObject = None
 
 def createConfigurationPage(configDlg):
@@ -135,8 +146,11 @@ class VcsPySvnPlugin(object):
         
         from VcsPlugins.vcsPySvn.ProjectHelper import SvnProjectHelper
         self.__projectHelperObject = SvnProjectHelper(None, None)
-        e4App().registerPluginObject(pluginTypename, self.__projectHelperObject, 
-                                     pluginType)
+        try:
+            e4App().registerPluginObject(pluginTypename, self.__projectHelperObject, 
+                                         pluginType)
+        except KeyError:
+            pass    # ignore duplicate registration
         readShortcuts(pluginName = pluginTypename)
     
     def getProjectHelper(self):
