@@ -20,6 +20,8 @@ from Preferences.Shortcuts import readShortcuts
 
 from VcsPlugins.vcsSubversion.SvnUtilities import getConfigPath, getServersPath
 
+import Utilities
+
 name = "Subversion Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = False
@@ -27,7 +29,6 @@ deactivateable = True
 version = "4.3.0"
 pluginType = "version_control"
 pluginTypename = "Subversion"
-displayString = QApplication.translate('VcsSubversionPlugin', 'Subversion (svn)')
 className = "VcsSubversionPlugin"
 packageName = "__core__"
 shortDescription = "Implements the Subversion version control interface."
@@ -67,12 +68,30 @@ def getVcsSystemIndicator():
     @return dictionary with indicator as key and a tuple with the vcs name (string)
         and vcs display string (QString)
     """
-    global displayString, pluginTypename
+    global pluginTypename
     data = {}
-    data[".svn"] = (pluginTypename, displayString)
-    data["_svn"] = (pluginTypename, displayString)
+    exe = 'svn'
+    if Utilities.isWindowsPlatform():
+        exe += '.exe'
+    if Utilities.isinpath(exe):
+        data[".svn"] = (pluginTypename, displayString())
+        data["_svn"] = (pluginTypename, displayString())
     return data
 
+def displayString():
+    """
+    Public function to get the display string.
+    
+    @return display string (QString)
+    """
+    exe = 'svn'
+    if Utilities.isWindowsPlatform():
+        exe += '.exe'
+    if Utilities.isinpath(exe):
+        return QApplication.translate('VcsSubversionPlugin', 'Subversion (svn)')
+    else:
+        return QString()
+
 subversionCfgPluginObject = None
 
 def createConfigurationPage(configDlg):
@@ -129,8 +148,11 @@ class VcsSubversionPlugin(object):
         
         from VcsPlugins.vcsSubversion.ProjectHelper import SvnProjectHelper
         self.__projectHelperObject = SvnProjectHelper(None, None)
-        e4App().registerPluginObject(pluginTypename, self.__projectHelperObject, 
-                                     pluginType)
+        try:
+            e4App().registerPluginObject(pluginTypename, self.__projectHelperObject, 
+                                         pluginType)
+        except KeyError:
+            pass    # ignore duplicate registration
         readShortcuts(pluginName = pluginTypename)
     
     def getProjectHelper(self):
