@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -22,7 +22,7 @@ name = "QRegExp Wizard Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "4.1.0"
+version = "4.2.0"
 className = "QRegExpWizard"
 packageName = "__core__"
 shortDescription = "Show the QRegExp wizard."
@@ -77,7 +77,7 @@ class QRegExpWizard(QObject):
             """ needed to create a QRegExp. The generated code is inserted"""
             """ at the current cursor position.</p>"""
         ))
-        self.action.connectIt(SIGNAL('triggered()'), self.__handle)
+        self.connect(self.action, SIGNAL('triggered()'), self.__handle)
         
         self.__ui.addE4Actions([self.action], 'wizards')
 
