@@ -142,10 +142,10 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
             tmpdir = Utilities.getEnvironmentEntry('TMPDIR')
         elif Utilities.hasEnvironmentEntry('TMP'):
             tmpdir = Utilities.getEnvironmentEntry('TMP')
-        elif os.path.exists('/usr/tmp'):
-            tmpdir = '/usr/tmp'
         elif os.path.exists('/var/tmp'):
             tmpdir = '/var/tmp'
+        elif os.path.exists('/usr/tmp'):
+            tmpdir = '/usr/tmp'
         elif os.path.exists('/tmp'):
             tmpdir = '/tmp'
         else:
@@ -155,6 +155,8 @@ class SvnDiffDialog(QWidget, SvnDialogMixin, Ui_SvnDiffDialog):
             return
         
         tmpdir = os.path.join(tmpdir, 'svn_tmp')
+        if not os.path.exists(tmpdir):
+            os.mkdir(tmpdir)
         
         opts = self.vcs.options['global'] + self.vcs.options['diff']
         recurse = "--non-recursive" not in opts
