@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -41,6 +41,7 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog)
         
         self.vcs = vcs
         
+        self.tagList.headerItem().setText(self.tagList.columnCount(), "")
         self.tagList.header().setSortIndicator(3, Qt.AscendingOrder)
         
         self.client = self.vcs.getClient()
@@ -59,6 +60,8 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog)
         @param tags flag indicating a list of tags is requested
                 (False = branches, True = tags)
         """
+        self.errorGroup.hide()
+        
         if not tags:
             self.setWindowTitle(self.trUtf8("Subversion Branches List"))
         self.activateWindow()
@@ -174,6 +177,7 @@ class SvnTagBranchListDialog(QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog)
         
         @param msg error message to show (string or QString)
         """
+        self.errorGroup.show()
         self.errors.insertPlainText(msg)
         self.errors.ensureCursorVisible()
         
