@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -97,6 +97,7 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         @keyparam summary flag indicating a summarizing diff 
             (only valid for URL diffs) (boolean)
         """
+        self.errorGroup.hide()
         self.intercept = False
         self.filename = fn
         
@@ -109,6 +110,8 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         args.append('diff')
         self.vcs.addArguments(args, self.vcs.options['global'])
         self.vcs.addArguments(args, self.vcs.options['diff'])
+        if '--diff-cmd' in self.vcs.options['diff']:
+            self.buttonBox.button(QDialogButtonBox.Save).hide()
         
         if versions is not None:
             try:
@@ -239,6 +242,7 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
         error pane.
         """
         if self.process is not None:
+            self.errorGroup.show()
             s = QString(self.process.readAllStandardError())
             self.errors.insertPlainText(s)
             self.errors.ensureCursorVisible()
@@ -338,7 +342,7 @@ class SvnDiffDialog(QWidget, Ui_SvnDiffDialog):
             self.errors.insertPlainText(input)
             self.errors.ensureCursorVisible()
         
-        self.proc.write(input.toLocal8Bit())
+        self.process.write(input.toLocal8Bit())
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
