@@ -58,4 +58,4 @@ class SvnPropSetDialog(QDialog, Ui_SvnPropSetDialog):
         if self.fileRadioButton.isChecked():
             return (self.propNameEdit.text(), True, self.propFileEdit.text())
         else:
-            return (self.propNameEdit.text(), False, self.propTextEdit.text())
+            return (self.propNameEdit.text(), False, self.propTextEdit.toPlainText())
