@@ -456,6 +456,8 @@ class Subversion(VersionControl):
             self.disconnect(self.__commitDialog, SIGNAL("accepted()"), 
                             self.__vcsCommit_Step2)
             self.__commitDialog = None
+        else:
+            changelists, keepChangelists = QStringList(), False
         
         if msg.isEmpty():
             msg = QString('***')
@@ -1287,7 +1289,7 @@ class Subversion(VersionControl):
         @param name file/directory name to be resolved (string)
         """
         args = QStringList()
-        if self.vcs.versionStr >= '1.5.0':
+        if self.versionStr >= '1.5.0':
             args.append('resolve')
             args.append('--accept')
             args.append('working')
