@@ -311,12 +311,24 @@ class TabWidget(E4TabWidget):
         """
         fn = editor.getFileName()
         if fn:
-            txt = os.path.basename(fn)
+            if Preferences.getUI("TabViewManagerFilenameOnly"):
+                txt = os.path.basename(fn)
+            else:
+                txt = fn
+                ppath = e4App().getObject("Project").getProjectPath()
+                if ppath:
+                    txt = txt.replace(ppath + os.sep, "")
+            
+            maxFileNameChars = Preferences.getUI("TabViewManagerFilenameLength")
+            if len(txt) > maxFileNameChars:
+                txt = "...%s" % txt[-maxFileNameChars:]
             if editor.isReadOnly():
                 txt = self.trUtf8("%1 (ro)").arg(txt)
+            
             index = self.indexOf(editor)
             if index > -1:
                 self.setTabText(index, txt)
+                self.setTabToolTip(index, fn)
         
     def removeWidget(self, object):
         """
@@ -1002,4 +1014,4 @@ class Tabview(QSplitter, ViewManager):
         for tw in self.tabWidgets:
             if id(tw) == id_:
                 return tw
-        return None
\ No newline at end of file
+        return None
