@@ -478,13 +478,15 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                         QTableWidgetItem(QString.number(len(matchobj.group(0)))))
                     
                     for i in range(1, captures + 1):
-                        self.resultTable.insertRow(row + i)
-                        self.resultTable.setItem(row + i, 0, 
-                            QTableWidgetItem(self.trUtf8("Capture #%1").arg(i)))
-                        self.resultTable.setItem(row + i, 1, 
-                            QTableWidgetItem(matchobj.group(i)))
-                        self.resultTable.setItem(row + i, 2, 
-                            QTableWidgetItem(QString.number(len(matchobj.group(i)))))
+                        if matchobj.group(i) is not None:
+                            row += 1
+                            self.resultTable.insertRow(row)
+                            self.resultTable.setItem(row, 0, 
+                                QTableWidgetItem(self.trUtf8("Capture #%1").arg(i)))
+                            self.resultTable.setItem(row, 1, 
+                                QTableWidgetItem(matchobj.group(i)))
+                            self.resultTable.setItem(row, 2, 
+                                QTableWidgetItem(QString.number(len(matchobj.group(i)))))
                     
                     # highlight the matched text
                     tc = self.textTextEdit.textCursor()
@@ -598,8 +600,16 @@ class PyRegExpWizardDialog(QDialog):
         """
         QDialog.__init__(self, parent)
         self.setModal(fromEric)
+        self.setSizeGripEnabled(True)
+        
+        self.__layout = QVBoxLayout(self)
+        self.__layout.setMargin(0)
+        self.setLayout(self.__layout)
         
         self.cw = PyRegExpWizardWidget(self, fromEric)
+        size = self.cw.size()
+        self.__layout.addWidget(self.cw)
+        self.resize(size)
         
         self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.accept)
         self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.reject)
