@@ -394,13 +394,15 @@ class QRegExpWizardWidget(QWidget, Ui_QRegExpWizardDialog):
                 
                 if not wildcard:
                     for i in range(1, captures + 1):
-                        self.resultTable.insertRow(row + i)
-                        self.resultTable.setItem(row + i, 0, 
-                            QTableWidgetItem(self.trUtf8("Capture #%1").arg(i)))
-                        self.resultTable.setItem(row + i, 1, 
-                            QTableWidgetItem(re.cap(i)))
-                        self.resultTable.setItem(row + i, 2, 
-                            QTableWidgetItem(QString.number(re.cap(i).length())))
+                        if re.cap(i).length() > 0:
+                            row += 1
+                            self.resultTable.insertRow(row)
+                            self.resultTable.setItem(row, 0, 
+                                QTableWidgetItem(self.trUtf8("Capture #%1").arg(i)))
+                            self.resultTable.setItem(row, 1, 
+                                QTableWidgetItem(re.cap(i)))
+                            self.resultTable.setItem(row, 2, 
+                                QTableWidgetItem(QString.number(re.cap(i).length())))
                 else:
                     self.resultTable.setRowCount(3)
                     
@@ -498,8 +500,16 @@ class QRegExpWizardDialog(QDialog):
         """
         QDialog.__init__(self, parent)
         self.setModal(fromEric)
+        self.setSizeGripEnabled(True)
+        
+        self.__layout = QVBoxLayout(self)
+        self.__layout.setMargin(0)
+        self.setLayout(self.__layout)
         
         self.cw = QRegExpWizardWidget(self, fromEric)
+        size = self.cw.size()
+        self.__layout.addWidget(self.cw)
+        self.resize(size)
         
         self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.accept)
         self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.reject)
