@@ -49,8 +49,11 @@ class EditorStylesPage(ConfigurationPageBase, Ui_EditorStylesPage):
         self.editorColours = {}
         
         # set initial values
-        self.foldingStyleComboBox.setCurrentIndex(
-            self.foldStyles.index(Preferences.getEditor("FoldingStyle")))
+        try:
+            self.foldingStyleComboBox.setCurrentIndex(
+                self.foldStyles.index(Preferences.getEditor("FoldingStyle")))
+        except ValueError:
+            self.foldingStyleComboBox.setCurrentIndex(0)
         self.marginsFont = Preferences.getEditorOtherFonts("MarginsFont")
         self.marginsFontSample.setFont(self.marginsFont)
         self.defaultFont = Preferences.getEditorOtherFonts("DefaultFont")
@@ -359,4 +362,4 @@ def create(dlg):
     @param dlg reference to the configuration dialog
     """
     page = EditorStylesPage()
-    return page
\ No newline at end of file
+    return page
