@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Module implementing the Email configuration page.
 """
 
+from PyQt4.QtGui import QIntValidator
+
 from ConfigurationPageBase import ConfigurationPageBase
 from Ui_EmailPage import Ui_EmailPage
 
@@ -24,8 +26,12 @@ class EmailPage(ConfigurationPageBase, Ui_EmailPage):
         self.setupUi(self)
         self.setObjectName("EmailPage")
         
+        self.portValidator = QIntValidator(1, 65535, self.portEdit)
+        self.portEdit.setValidator(self.portValidator)
+        
         # set initial values
         self.mailServerEdit.setText(Preferences.getUser("MailServer"))
+        self.portEdit.setText("%d" % Preferences.getUser("MailServerPort"))
         self.emailEdit.setText(Preferences.getUser("Email"))
         self.signatureEdit.setPlainText(Preferences.getUser("Signature"))
         self.mailAuthenticationCheckBox.setChecked(\
@@ -33,6 +39,8 @@ class EmailPage(ConfigurationPageBase, Ui_EmailPage):
         self.mailUserEdit.setText(Preferences.getUser("MailServerUser"))
         self.mailPasswordEdit.setText(\
             Preferences.getUser("MailServerPassword"))
+        self.useTlsCheckBox.setChecked(\
+            Preferences.getUser("MailServerUseTLS"))
         
     def save(self):
         """
@@ -40,6 +48,8 @@ class EmailPage(ConfigurationPageBase, Ui_EmailPage):
         """
         Preferences.setUser("MailServer",
             self.mailServerEdit.text())
+        Preferences.setUser("MailServerPort", 
+            int(self.portEdit.text()))
         Preferences.setUser("Email",
             self.emailEdit.text())
         Preferences.setUser("Signature",
@@ -50,6 +60,8 @@ class EmailPage(ConfigurationPageBase, Ui_EmailPage):
             self.mailUserEdit.text())
         Preferences.setUser("MailServerPassword",
             self.mailPasswordEdit.text())
+        Preferences.setUser("MailServerUseTLS",
+            int(self.useTlsCheckBox.isChecked()))
     
 def create(dlg):
     """
