@@ -12,7 +12,7 @@ from PyQt4.QtGui import QButtonGroup
 try:
     from PyQt4.QtWebKit import QWebSettings
     webkit = True
-except ImportException:
+except ImportError:
     webkit = False
 
 from KdeQt import KQFileDialog
