@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -53,6 +53,10 @@ class ViewmanagerPage(ConfigurationPageBase, Ui_ViewmanagerPage):
         
         self.filenameLengthSpinBox.setValue(
             Preferences.getUI("TabViewManagerFilenameLength"))
+        self.filenameOnlyCheckBox.setChecked(
+            Preferences.getUI("TabViewManagerFilenameOnly"))
+        self.recentFilesSpinBox.setValue(
+            Preferences.getUI("RecentNumber"))
         
     def save(self):
         """
@@ -63,6 +67,10 @@ class ViewmanagerPage(ConfigurationPageBase, Ui_ViewmanagerPage):
         Preferences.setViewManager(vm)
         Preferences.setUI("TabViewManagerFilenameLength",
             self.filenameLengthSpinBox.value())
+        Preferences.setUI("TabViewManagerFilenameOnly",
+            int(self.filenameOnlyCheckBox.isChecked()))
+        Preferences.setUI("RecentNumber", 
+            self.recentFilesSpinBox.value())
         
     @pyqtSignature("int")
     def on_windowComboBox_activated(self, index):
