@@ -199,7 +199,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                 version = enchant.__version__
             except AttributeError:
                 version = self.trUtf8("(unknown)")
-        except ImportError:
+        except (ImportError, AttributeError, OSError):
             text = "enchant"
             version = ""
         self.__createEntry(self.trUtf8("Spell Checker - PyEnchant"), text, version)
