@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -19,6 +19,7 @@ from ShortcutDialog import ShortcutDialog
 import UI.PixmapCache
 
 import Preferences
+from Preferences import Shortcuts
 
 
 class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
@@ -27,6 +28,7 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
     """
     objectNameRole = Qt.UserRole
     noCheckRole    = Qt.UserRole + 1
+    objectTypeRole = Qt.UserRole + 2
     
     def __init__(self, parent = None, name = None, modal = False):
         """
@@ -43,6 +45,7 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
         self.setupUi(self)
         
         self.clearSearchButton.setIcon(UI.PixmapCache.getIcon("clearLeft.png"))
+        self.shortcutsList.headerItem().setText(self.shortcutsList.columnCount(), "")
         self.shortcutsList.header().setSortIndicator(0, Qt.AscendingOrder)
         
         self.shortcutDialog = ShortcutDialog()
@@ -71,17 +74,20 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
         @return reference to the category item (QTreeWidgetItem)
         """
         itm = QTreeWidgetItem(self.shortcutsList, QStringList(title))
-        self.shortcutsList.setItemExpanded(itm, True)
+        itm.setExpanded(True)
         return itm
         
-    def __generateShortcutItem(self, category, action, noCheck = False):
+    def __generateShortcutItem(self, category, action, 
+                               noCheck = False, objectType = None):
         """
         Private method to generate a keyboard shortcut item.
         
         @param category reference to the category item (QTreeWidgetItem)
         @param action reference to the keyboard action (E4Action)
-        @param noCheck flag indicating that no uniqueness check should
+        @keyparam noCheck flag indicating that no uniqueness check should
             be performed (boolean)
+        @keyparam objectType type of the object (string). Objects of the same type
+            are not checked for duplicate shortcuts.
         """
         itm = QTreeWidgetItem(category, 
             QStringList() << action.iconText() << QString(action.shortcut().toString()) \
@@ -89,16 +95,23 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
         itm.setIcon(0, action.icon())
         itm.setData(0, self.objectNameRole, QVariant(action.objectName()))
         itm.setData(0, self.noCheckRole, QVariant(noCheck))
+        if objectType:
+            itm.setData(0, self.objectTypeRole, QVariant(objectType))
+        else:
+            itm.setData(0, self.objectTypeRole, QVariant())
         
-    def showEvent(self, evt):
+    def populate(self):
         """
-        Public method called when the dialog is about to be shown.
-        
-        @param evt the event (QShowEvent)
+        Public method to populate the dialog.
         """
         self.searchEdit.clear()
         self.searchEdit.setFocus()
         self.shortcutsList.clear()
+        self.actionButton.setChecked(True)
+        
+        # let the plugin manager create on demand plugin objects
+        pm = e4App().getObject("PluginManager")
+        pm.initOnDemandPlugins()
         
         # populate the various lists
         self.projectItem = self.__generateCategoryItem(self.trUtf8("Project"))
@@ -141,6 +154,10 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
         for act in e4App().getObject("ViewManager").getActions('bookmark'):
             self.__generateShortcutItem(self.bookmarkItem, act)
         
+        self.spellingItem = self.__generateCategoryItem(self.trUtf8("Spelling"))
+        for act in e4App().getObject("ViewManager").getActions('spelling'):
+            self.__generateShortcutItem(self.spellingItem, act)
+        
         actions = e4App().getObject("ViewManager").getActions('window')
         if actions:
             self.windowItem = self.__generateCategoryItem(self.trUtf8("Window"))
@@ -151,8 +168,10 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
         for category, ref in e4App().getPluginObjects():
             if hasattr(ref, "getActions"):
                 categoryItem = self.__generateCategoryItem(category)
+                objectType = e4App().getPluginObjectType(category)
                 for act in ref.getActions():
-                    self.__generateShortcutItem(categoryItem, act)
+                    self.__generateShortcutItem(categoryItem, act, 
+                                                objectType = objectType)
                 self.pluginCategoryItems.append(categoryItem)
         
         self.helpViewerItem = self.__generateCategoryItem(self.trUtf8("Help Viewer"))
@@ -162,6 +181,8 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
         self.__resort()
         self.__resizeColumns()
         
+        self.__editTopItem = None
+        
     def on_shortcutsList_itemDoubleClicked(self, itm, column):
         """
         Private slot to handle a double click in the shortcuts list.
@@ -171,9 +192,12 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
         """
         if itm.childCount():
             return
-            
+        
+        self.__editTopItem = itm.parent()
+        
         self.shortcutDialog.setKeys(QKeySequence(itm.text(1)), QKeySequence(itm.text(2)), 
-            itm.data(0, self.noCheckRole).toBool())
+            itm.data(0, self.noCheckRole).toBool(), 
+            itm.data(0, self.objectTypeRole).toString())
         self.shortcutDialog.show()
         
     def on_shortcutsList_itemClicked(self, itm, column):
@@ -198,13 +222,15 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
         if column != 0:
             keystr = unicode(itm.text(column)).title()
             if not itm.data(0, self.noCheckRole).toBool() and \
-               not self.__checkShortcut(QKeySequence(keystr)):
+               not self.__checkShortcut(QKeySequence(keystr), 
+                                        itm.data(0, self.objectTypeRole).toString(), 
+                                        itm.parent()):
                 itm.setText(column, "")
             else:
                 itm.setText(column, keystr)
             self.shortcutsList.closePersistentEditor(itm, column)
 
-    def __shortcutChanged(self, keysequence, altKeysequence,  noCheck):
+    def __shortcutChanged(self, keysequence, altKeysequence, noCheck, objectType):
         """
         Private slot to handle the shortcutChanged signal of the shortcut dialog.
         
@@ -213,10 +239,11 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
             action (QKeySequence)
         @param noCheck flag indicating that no uniqueness check should
             be performed (boolean)
+        @param objectType type of the object (string).
         """
         if not noCheck and \
-           (not self.__checkShortcut(keysequence) or \
-            not self.__checkShortcut(altKeysequence)):
+           (not self.__checkShortcut(keysequence, objectType, self.__editTopItem) or \
+            not self.__checkShortcut(altKeysequence, objectType, self.__editTopItem)):
             return
         
         self.shortcutsList.currentItem().setText(1, QString(keysequence))
@@ -225,11 +252,15 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
         self.__resort()
         self.__resizeColumns()
         
-    def __checkShortcut(self, keysequence):
+    def __checkShortcut(self, keysequence, objectType, origTopItem):
         """
         Private method to check a keysequence for uniqueness.
         
         @param keysequence the keysequence to check (QKeySequence)
+        @param objectType type of the object (string). Entries with the same
+            object type are not checked for uniqueness.
+        @param origTopItem refrence to the parent of the item to be checked
+            (QTreeWidgetItem)
         @return flag indicating uniqueness (boolean)
         """
         if keysequence.isEmpty():
@@ -241,8 +272,20 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
             topItem = self.shortcutsList.topLevelItem(topIndex)
             for index in range(topItem.childCount()):
                 itm = topItem.child(index)
-                if unicode(itm.text(0)) != keyname and \
-                   not itm.data(0, self.noCheckRole).toBool():
+                
+                # 1. shall a check be performed?
+                if itm.data(0, self.noCheckRole).toBool():
+                    continue
+                
+                # 2. check object type
+                itmObjectType = itm.data(0, self.objectTypeRole).toString()
+                if itmObjectType and \
+                   itmObjectType == objectType and \
+                   topItem != origTopItem:
+                    continue
+                
+                # 3. check key name
+                if unicode(itm.text(0)) != keyname:
                     for col in [1, 2]:  # check against primary, then alternative binding
                         itmseq = unicode(itm.text(col))
                         # step 1: check if shortcut is already allocated
@@ -346,6 +389,8 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
             e4App().getObject("ViewManager").getActions('macro'))
         self.__saveCategoryActions(self.bookmarkItem, 
             e4App().getObject("ViewManager").getActions('bookmark'))
+        self.__saveCategoryActions(self.spellingItem, 
+            e4App().getObject("ViewManager").getActions('spelling'))
         
         actions = e4App().getObject("ViewManager").getActions('window')
         if actions:
@@ -360,7 +405,7 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
         self.__saveCategoryActions(self.helpViewerItem, 
             e4App().getObject("DummyHelpViewer").getActions())
         
-        Preferences.saveShortcuts()
+        Shortcuts.saveShortcuts()
         Preferences.syncPreferences()
         
         self.emit(SIGNAL('updateShortcuts'))
@@ -378,7 +423,11 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
             childHiddenCount = 0
             for index in range(topItem.childCount()):
                 itm = topItem.child(index)
-                if not itm.text(0).contains(QRegExp(txt, Qt.CaseInsensitive)):
+                if (self.actionButton.isChecked() and \
+                    not itm.text(0).contains(QRegExp(txt, Qt.CaseInsensitive))) or \
+                   (self.shortcutButton.isChecked() and \
+                    not itm.text(1).contains(txt, Qt.CaseInsensitive) and \
+                    not itm.text(2).contains(txt, Qt.CaseInsensitive)):
                     itm.setHidden(True)
                     childHiddenCount += 1
                 else:
@@ -391,3 +440,23 @@ class ShortcutsDialog(QDialog, Ui_ShortcutsDialog):
         Private slot called by a click of the clear search button.
         """
         self.searchEdit.clear()
+    
+    @pyqtSignature("bool")
+    def on_actionButton_toggled(self, checked):
+        """
+        Private slot called, when the action radio button is toggled.
+        
+        @param checked state of the action radio button (boolean)
+        """
+        if checked:
+            self.on_searchEdit_textChanged(self.searchEdit.text())
+    
+    @pyqtSignature("bool")
+    def on_shortcutButton_toggled(self, checked):
+        """
+        Private slot called, when the shortcuts radio button is toggled.
+        
+        @param checked state of the shortcuts radio button (boolean)
+        """
+        if checked:
+            self.on_searchEdit_textChanged(self.searchEdit.text())
