@@ -195,7 +195,7 @@ class Prefs(object):
         "ShowWhitespace" : 0,
         "ShowEOL" : 0,
         "UseMonospacedFont" : 0,
-        "WrapLongLines" : 1,
+        "WrapLongLines" : 0,
         "WarnFilesize" : 512,
         "ClearBreaksOnClose" : 1,
         "StripTrailingWhitespace" : 0, 
@@ -557,8 +557,11 @@ class Prefs(object):
         "LinenoMargin" : 1,
         "MaxHistoryEntries" : 100,
         "SyntaxHighlightingEnabled" : 1,
-        "ReadRcFile" : 1, 
+        "Shell" : "", 
+        "ShellInteractive" : 1, 
     }
+    if sys.platform.lower().startswith("linux"):
+        terminalDefaults["Shell"] = "bash"
 
     # defaults for Qt related stuff
     qtDefaults = {
@@ -780,7 +783,7 @@ def exportPreferences(prefClass = Prefs):
         settingsFile = unicode(prefClass.settings.fileName())
         prefClass.settings = None
         shutil.copy(settingsFile, unicode(filename))
-        syncPreferences()
+        initPreferences()
 
 def importPreferences(prefClass = Prefs):
     """
@@ -1370,6 +1373,10 @@ def getTerminal(key, prefClass = Prefs):
     @param prefClass preferences class used as the storage area
     @return the requested shell setting
     """
+    if key in ["Shell"]:
+        return prefClass.settings.value("Terminal/" + key,
+            QtCore.QVariant(prefClass.terminalDefaults[key])).toString()
+    
     return prefClass.settings.value("Terminal/" + key,
         QtCore.QVariant(prefClass.terminalDefaults[key])).toInt()[0]
 
