@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -82,10 +82,11 @@ class AddFileDialog(QDialog, Ui_AddFileDialog):
                 dir = self.targetDirEdit.text()
         if self.filter is None:
             patterns = {
-                "SOURCES"    : QStringList(), 
-                "FORMS"      : QStringList(), 
-                "RESOURCES"  : QStringList(), 
-                "INTERFACES" : QStringList(), 
+                "SOURCES"      : QStringList(), 
+                "FORMS"        : QStringList(), 
+                "RESOURCES"    : QStringList(), 
+                "INTERFACES"   : QStringList(), 
+                "TRANSLATIONS" : QStringList(), 
             }
             for pattern, filetype in self.filetypes.items():
                 if patterns.has_key(filetype):
@@ -95,12 +96,13 @@ class AddFileDialog(QDialog, Ui_AddFileDialog):
                 "Forms Files (%2);;"
                 "Resource Files (%3);;"
                 "Interface Files (%4);;"
-                "Translation Files (*.ts *.qm);;"
+                "Translation Files (%5);;"
                 "All Files (*)")\
                 .arg(patterns["SOURCES"].join(" "))\
                 .arg(patterns["FORMS"].join(" "))\
                 .arg(patterns["RESOURCES"].join(" "))\
-                .arg(patterns["INTERFACES"].join(" "))
+                .arg(patterns["INTERFACES"].join(" "))\
+                .arg(patterns["TRANSLATIONS"].join(" "))
             caption = self.trUtf8("Select Files")
         elif self.filter == 'form':
             patterns = QStringList()
@@ -135,7 +137,12 @@ class AddFileDialog(QDialog, Ui_AddFileDialog):
                 .arg(patterns.join(" "))
             caption = self.trUtf8("Select interface files")
         elif self.filter == 'translation':
-            dfilter = self.trUtf8("Translation Files (*.ts *.qm)")
+            patterns = QStringList()
+            for pattern, filetype in self.filetypes.items():
+                if filetype == "TRANSLATIONS":
+                    patterns.append(QString(pattern))
+            dfilter = self.trUtf8("Translation Files (%1)")\
+                .arg(patterns.join(" "))
             caption = self.trUtf8("Select translation files")
         elif self.filter == 'others':
             dfilter = self.trUtf8("All Files (*)")
