@@ -15,6 +15,7 @@ from PyQt4.QtGui import *
 from PyQt4 import uic
 
 from KdeQt import KQMessageBox
+from KdeQt.KQApplication import e4App
 
 from NewDialogClassDialog import NewDialogClassDialog
 from Ui_CreateDialogCodeDialog import Ui_CreateDialogCodeDialog
@@ -46,6 +47,8 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         
         self.okButton = self.buttonBox.button(QDialogButtonBox.Ok)
         
+        self.slotsView.header().hide()
+        
         self.project = project
         
         self.formFile = unicode(formName)
@@ -65,6 +68,12 @@ class CreateDialogCodeDialog(QDialog, Ui_CreateDialogCodeDialog):
         self.__module = None
         
         if os.path.exists(self.srcFile):
+            vm = e4App().getObject("ViewManager")
+            ed = vm.getOpenEditor(self.srcFile)
+            if ed and not vm.checkDirty(ed):
+                self.__initError = True
+                return
+            
             self.__module = ModuleParser.readModule(self.srcFile, caching = False)
         
         if self.__module is not None:
