@@ -217,6 +217,8 @@ class ProjectBaseBrowser(Browser):
         Protected slot to handle the projectOpened signal.
         """
         self.layoutDisplay()
+        self.sortByColumn(0, Qt.DescendingOrder)
+        self.sortByColumn(0, Qt.AscendingOrder)
         self._initMenusAndVcs()
         
     def _initMenusAndVcs(self):
@@ -239,6 +241,8 @@ class ProjectBaseBrowser(Browser):
         Protected slot to handle the newProject signal.
         """
         self.layoutDisplay()
+        self.sortByColumn(0, Qt.DescendingOrder)
+        self.sortByColumn(0, Qt.AscendingOrder)
         
         self._createPopupMenus()
         
