@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -14,7 +14,9 @@ from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 
 from UI.Browser import Browser
+
 from E4Gui.E4TabWidget import E4TabWidget
+from E4Gui.E4Led import E4Led
 
 from ProjectSourcesBrowser import ProjectSourcesBrowser
 from ProjectFormsBrowser import ProjectFormsBrowser
@@ -26,18 +28,9 @@ from ProjectOthersBrowser import ProjectOthersBrowser
 import UI.PixmapCache
 import Preferences
 
-SourcesBrowserFlag      =  1
-FormsBrowserFlag        =  2
-ResourcesBrowserFlag    =  4
-TranslationsBrowserFlag =  8
-InterfacesBrowserFlag   = 16
-OthersBrowserFlag       = 32
-AllBrowsersFlag         = SourcesBrowserFlag | \
-                          FormsBrowserFlag | \
-                          ResourcesBrowserFlag | \
-                          TranslationsBrowserFlag | \
-                          InterfacesBrowserFlag | \
-                          OthersBrowserFlag
+from ProjectBrowserFlags import SourcesBrowserFlag, FormsBrowserFlag, \
+    ResourcesBrowserFlag, TranslationsBrowserFlag, InterfacesBrowserFlag, \
+    OthersBrowserFlag, AllBrowsersFlag
 
 class ProjectBrowser(E4TabWidget):
     """
@@ -68,6 +61,25 @@ class ProjectBrowser(E4TabWidget):
         
         self.setWindowIcon(UI.PixmapCache.getIcon("eric.png"))
         
+        self.vcsStatusIndicator = E4Led(self)
+        self.setCornerWidget(self.vcsStatusIndicator, Qt.TopLeftCorner)
+        self.vcsStatusColorNames = {
+            "A" : "VcsAdded",
+            "M" : "VcsModified",
+            "R" : "VcsReplaced", 
+            "U" : "VcsUpdate",
+            "Z" : "VcsConflict",
+        }
+        self.vcsStatusText = {
+            " " : self.trUtf8("up to date"), 
+            "A" : self.trUtf8("files added"), 
+            "M" : self.trUtf8("local modifications"), 
+            "R" : self.trUtf8("files replaced"), 
+            "U" : self.trUtf8("update required"), 
+            "Z" : self.trUtf8("conflict"), 
+        }
+        self.__vcsStateChanged(" ")
+        
         # step 1: create all the individual browsers
         # sources browser
         self.psBrowser = ProjectSourcesBrowser(self.project)
@@ -158,6 +170,8 @@ class ProjectBrowser(E4TabWidget):
         self.connect(self.project, SIGNAL('projectPropertiesChanged'),
                 self.__projectPropertiesChanged)
         self.connect(self, SIGNAL("currentChanged(int)"), self.__currentChanged)
+        self.connect(self.project.getModel(), SIGNAL("vcsStateChanged"), 
+                self.__vcsStateChanged)
         
         self.__currentBrowsersFlags = 0
         self.__projectPropertiesChanged()
@@ -239,6 +253,7 @@ class ProjectBrowser(E4TabWidget):
         """
         self.__projectPropertiesChanged()
         self.setCurrentIndex(0)
+        self.__vcsStateChanged(" ")
         
     def __projectClosed(self):
         """
@@ -250,6 +265,7 @@ class ProjectBrowser(E4TabWidget):
         else:
             self.setCurrentIndex(0)
         self.__setSourcesIcon()
+        self.__vcsStateChanged(" ")
         
     def __newProject(self):
         """
@@ -353,3 +369,18 @@ class ProjectBrowser(E4TabWidget):
         Public slot used to handle the preferencesChanged signal.
         """
         self.__projectPropertiesChanged()
+        self.__vcsStateChanged(self.currentVcsStatus)
+    
+    def __vcsStateChanged(self, state):
+        """
+        Private slot to handle a change in the vcs state.
+        
+        @param state new vcs state (string)
+        """
+        self.currentVcsStatus = state
+        if state == " " or state not in self.vcsStatusColorNames:
+            self.vcsStatusIndicator.setColor(QColor(Qt.lightGray))
+        else:
+            self.vcsStatusIndicator.setColor(\
+                Preferences.getProjectBrowserColour(self.vcsStatusColorNames[state]))
+        self.vcsStatusIndicator.setToolTip(self.vcsStatusText[state])
