@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -190,6 +190,8 @@ class ProjectBrowserFileItem(BrowserFileItem, ProjectBrowserItemMixin):
 class ProjectBrowserModel(BrowserModel):
     """
     Class implementing the project browser model.
+    
+    @signal vcsStateChanged(string) emitted after the VCS state has changed
     """
     def __init__(self, parent):
         """
@@ -220,6 +222,7 @@ class ProjectBrowserModel(BrowserModel):
         self.colorNames = {
             "A" : "VcsAdded",
             "M" : "VcsModified",
+            "R" : "VcsReplaced", 
             "U" : "VcsUpdate",
             "Z" : "VcsConflict",
         }
@@ -227,6 +230,7 @@ class ProjectBrowserModel(BrowserModel):
             " " : QColor(),
             "A" : Preferences.getProjectBrowserColour(self.colorNames["A"]),
             "M" : Preferences.getProjectBrowserColour(self.colorNames["M"]),
+            "R" : Preferences.getProjectBrowserColour(self.colorNames["R"]),
             "U" : Preferences.getProjectBrowserColour(self.colorNames["U"]),
             "Z" : Preferences.getProjectBrowserColour(self.colorNames["Z"]),
         }
@@ -332,6 +336,8 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method called after a project has been closed.
         """
+        self.__vcsStatus = {}
+        
         self.rootItem.removeChildren()
         self.reset()
         
@@ -342,6 +348,7 @@ class ProjectBrowserModel(BrowserModel):
         """
         Public method used to populate the model after a project has been opened.
         """
+        self.__vcsStatus = {}
         states = {}
         keys = self.projectBrowserTypes.keys()[:]
         
@@ -360,9 +367,10 @@ class ProjectBrowserModel(BrowserModel):
                     dir = os.path.join(self.project.ppath, dir)
                 states = self.project.vcs.vcsAllRegisteredStates(states, dir)
             
-            if self.project.pdata["TRANSLATIONPREFIX"]:
+            if self.project.pdata["TRANSLATIONPATTERN"]:
                 dir = os.path.join(self.project.ppath, 
-                                   self.project.pdata["TRANSLATIONPREFIX"][0])
+                                   self.project.pdata["TRANSLATIONPATTERN"][0])\
+                      .split("%language%")[0]
                 if not os.path.isdir(dir):
                     dir = os.path.dirname(dir)
                 states = self.project.vcs.vcsAllRegisteredStates(states, dir)
@@ -670,20 +678,32 @@ class ProjectBrowserModel(BrowserModel):
             states in the first column and the path relative to the project 
             directory starting with the third column. The allowed status flags 
             are:
-            <li>
-                <ul>"A" path was added but not yet comitted</ul>
-                <ul>"M" path has local changes</ul>
-                <ul>"U" path needs an update</ul>
-                <ul>"Z" path contains a conflict</ul>
-                <ul>" " path is back at normal</ul>
-            </li>
+            <ul>
+                <li>"A" path was added but not yet comitted</li>
+                <li>"M" path has local changes</li>
+                <li>"R" path was deleted and then re-added</li>
+                <li>"U" path needs an update</li>
+                <li>"Z" path contains a conflict</li>
+                <li>" " path is back at normal</li>
+            </ul>
         """
         statesList.sort()
         lastHead = ""
         itemCache = {}
+        if len(statesList) == 1 and statesList[0] == '--RESET--':
+            statesList = QStringList()
+            for name in self.__vcsStatus.keys():
+                statesList.append(" %s" % name)
+        
         for name in statesList:
             state = unicode(name)[0]
             name = unicode(name)[1:].strip()
+            if state == ' ':
+                if name in self.__vcsStatus:
+                    del self.__vcsStatus[name]
+            else:
+                self.__vcsStatus[name] = state
+            
             try:
                 itm = itemCache[name]
             except KeyError:
@@ -706,6 +726,11 @@ class ProjectBrowserModel(BrowserModel):
                 lastHead = head
         if lastHead:
             self.__changeParentsVCSState(lastHead, itemCache)
+        try:
+            globalVcsStatus = sorted(self.__vcsStatus.values())[-1]
+        except IndexError:
+            globalVcsStatus = ' '
+        self.emit(SIGNAL("vcsStateChanged"), globalVcsStatus)
 
     def __changeParentsVCSState(self, path, itemCache):
         """
