@@ -870,7 +870,7 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
                     args.append("-x")
             elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
                 self.compiledFile = ofn + '.rb'
-                if self.project.getProjectType() == "Kde":
+                if self.project.getProjectType() in ["Kde", "Kde4"]:
                     args.append('-kde')
                 args.append('-x')
             
@@ -912,9 +912,19 @@ class ProjectFormsBrowser(ProjectBaseBrowser):
             self.hooks["generateDialogCode"](filename)
         else:
             from CreateDialogCodeDialog import CreateDialogCodeDialog
+            
+            # change environment
+            sys.path.insert(0, self.project.getProjectPath())
+            cwd = os.getcwd()
+            os.chdir(os.path.dirname(os.path.abspath(fn)))
+            
             dlg = CreateDialogCodeDialog(fn, self.project, self)
             if not dlg.initError():
                 dlg.exec_()
+            
+            # reset the environment
+            os.chdir(cwd)
+            del sys.path[0]
         
     def __generateSubclass(self):
         """
