@@ -466,7 +466,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
     def __readStdout(self):
         """
         Private slot to handle the readyReadStandardOutput signal of the 
-        pyuic/rbuic process.
+        pyrcc4/rbrcc process.
         """
         if self.compileProc is None:
             return
@@ -478,7 +478,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
     def __readStderr(self):
         """
         Private slot to handle the readyReadStandardError signal of the 
-        pyuic/rbuic process.
+        pyrcc4/rbrcc process.
         """
         if self.compileProc is None:
             return
@@ -545,6 +545,8 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
         if self.project.pdata["PROGLANGUAGE"][0] == "Python":
             if self.project.getProjectType() in ["Qt4", "E4Plugin", "Kde4"]:
                 self.rccCompiler = 'pyrcc4'
+                if PYQT_VERSION >= 0x040500:
+                    args.append("-py2")
             else:
                 return None
         elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
@@ -568,7 +570,7 @@ class ProjectResourcesBrowser(ProjectBaseBrowser):
                                 self.RCFilenameFormatPython % filename)
         elif self.project.pdata["PROGLANGUAGE"][0] == "Ruby":
             self.compiledFile = os.path.join(
-                                dirname, self.RCFilenameFormatRuby %filename)
+                                dirname, self.RCFilenameFormatRuby % filename)
         
         args.append(fn)
         self.connect(self.compileProc, SIGNAL('finished(int, QProcess::ExitStatus)'),
