@@ -652,7 +652,7 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
         @return flag indicating success
         """
         path, ext = os.path.splitext(self.project.pfile)
-        pfile = '%s.e4x' % path
+        pfile = '%s_e4x.pro' % path
         
         # only consider files satisfying the filter criteria
         _sources = [s for s in self.project.pdata["SOURCES"] \
@@ -684,10 +684,13 @@ class ProjectTranslationsBrowser(ProjectBaseBrowser):
             l = [lang.fileName().replace(self.project.ppath+os.sep, '') \
                  for lang in langs if lang.fileName().endswith('.ts')]
         else:
-            pattern = unicode(self.project.pdata["TRANSLATIONPATTERN"][0])\
-                      .replace("%language%", "*")
-            l = [lang for lang in self.project.pdata["TRANSLATIONS"] \
-                 if fnmatch.fnmatch(lang, pattern)]
+            try:
+                pattern = unicode(self.project.pdata["TRANSLATIONPATTERN"][0])\
+                          .replace("%language%", "*")
+                l = [lang for lang in self.project.pdata["TRANSLATIONS"] \
+                     if fnmatch.fnmatch(lang, pattern)]
+            except IndexError:
+                l = []
         if l:
             sections.append(("TRANSLATIONS", l))
         else:
