@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -8,7 +8,7 @@ Module implementing a D lexer with some additional methods.
 """
 
 from PyQt4.Qsci import QsciLexerD, QsciScintilla
-from PyQt4.QtCore import QString
+from PyQt4.QtCore import QString, QStringList
 
 from Lexer import Lexer
 import Preferences
@@ -50,3 +50,32 @@ class LexerD(QsciLexerD, Lexer):
             indentStyle |= QsciScintilla.AiClosing
         self.setAutoIndentStyle(indentStyle)
         self.setFoldCompact(Preferences.getEditor("AllFoldCompact"))
+    
+    def autoCompletionWordSeparators(self):
+        """
+        Public method to return the list of separators for autocompletion.
+        
+        @return list of separators (QStringList)
+        """
+        return QStringList() << '.'
+    
+    def isCommentStyle(self, style):
+        """
+        Public method to check, if a style is a comment style.
+        
+        @return flag indicating a comment style (boolean)
+        """
+        return style in [QsciLexerD.Comment, 
+                         QsciLexerD.CommentDoc, 
+                         QsciLexerD.CommentLine, 
+                         QsciLexerD.CommentLineDoc, 
+                         QsciLexerD.CommentNested]
+    
+    def isStringStyle(self, style):
+        """
+        Public method to check, if a style is a string style.
+        
+        @return flag indicating a string style (boolean)
+        """
+        return style in [QsciLexerD.String, 
+                         QsciLexerD.UnclosedString]
