@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2007 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2007 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,9 +9,56 @@ Package implementing lexers for the various supported programming languages.
 
 from PyQt4.QtCore import QStringList
 from PyQt4.QtGui import QApplication
+from PyQt4.Qsci import QSCINTILLA_VERSION_STR
+
+from QScintilla.QsciScintillaCompat import QSCINTILLA_VERSION
 
 import Preferences
 
+# The lexer registry
+# Dictionary with the language name as key. Each entry is a list with
+#       0. display string (QString)
+#       1. dummy filename to derive lexer name (string)
+#       2. reference to a function instantiating the specific lexer
+#          This function must take a reference to the parent as argument.
+#       3. list of open file filters (QStringList)
+#       4. list of save file filters (QStringList)
+#       5. default lexer associations (list of strings of filename wildcard patterns
+#          to be associated with the lexer)
+LexerRegistry = {}
+
+def registerLexer(name, displayString, filenameSample, getLexerFunc, 
+                  openFilters = QStringList(), saveFilters = QStringList(), 
+                  defaultAssocs = []):
+    """
+    Module function to register a custom QScintilla lexer.
+    
+    @param name lexer language name (string)
+    @param displayString display string (QString)
+    @param filenameSample dummy filename to derive lexer name (string)
+    @param getLexerFunc reference to a function instantiating the specific lexer.
+        This function must take a reference to the parent as it's only argument.
+    @keyparam openFilters list of open file filters (QStringList)
+    @keyparam saveFilters list of save file filters (QStringList)
+    @keyparam defaultAssocs default lexer associations (list of strings of filename 
+        wildcard patterns to be associated with the lexer)
+    @exception KeyError raised when the given name is already in use
+    """
+    if name in LexerRegistry:
+        raise KeyError('Lexer "%s" already registered.' % name)
+    else:
+        LexerRegistry[name] = [displayString, filenameSample, getLexerFunc, 
+                               openFilters, saveFilters, defaultAssocs[:]]
+
+def unregisterLexer(name):
+    """
+    Module function to unregister a custom QScintilla lexer.
+    
+    @param name lexer language name (string)
+    """
+    if name in LexerRegistry:
+        del LexerRegistry[name]
+
 def getSupportedLanguages():
     """
     Module function to get a dictionary of supported lexer languages.
@@ -46,94 +93,155 @@ def getSupportedLanguages():
         "TeX"        : [QApplication.translate('Lexers', "TeX"),          'dummy.tex'],
         "VHDL"       : [QApplication.translate('Lexers', "VHDL"),         'dummy.vhd'], 
     }
-    # adjust list to various QScintilla versions
-    removeLanguages = []
-    for removeLanguage in removeLanguages:
-        del supportedLanguages[removeLanguage]
+    
+    if QSCINTILLA_VERSION() >= 0x020201:
+        supportedLanguages["TCL"] = [QApplication.translate('Lexers', "TCL"), 'dummy.tcl']
+        supportedLanguages["Fortran"] = \
+            [QApplication.translate('Lexers', "Fortran"), 'dummy.f95']
+        supportedLanguages["Fortran77"] = \
+            [QApplication.translate('Lexers', "Fortran77"), 'dummy.f']
+        supportedLanguages["Pascal"] = \
+            [QApplication.translate('Lexers', "Pascal"), 'dummy.pas']
+        supportedLanguages["PostScript"] = \
+            [QApplication.translate('Lexers', "PostScript"), 'dummy.ps']
+        supportedLanguages["XML"] = \
+            [QApplication.translate('Lexers', "XML"), 'dummy.xml']
+        supportedLanguages["YAML"] = \
+            [QApplication.translate('Lexers', "YAML"), 'dummy.yml']
+    
+    for name in LexerRegistry:
+        supportedLanguages[name] = LexerRegistry[name][:2]
+    
+    supportedLanguages["Guessed"] = \
+        [QApplication.translate('Lexers', "Pygments"), 'dummy.pygments']
     
     return supportedLanguages
 
-def getLexer(language, parent = None):
+def getLexer(language, parent = None, pyname = ""):
     """
     Module function to instantiate a lexer object for a given language.
     
     @param language language of the lexer (string)
     @param parent reference to the parent object (QObject)
+    @keyparam pyname name of the pygments lexer to use (string)
     @return reference to the instanciated lexer object (QsciLexer)
     """
-    try:
-        if language == "Python":
-            from LexerPython import LexerPython
-            return LexerPython(parent)
-        elif language == "C++":
-            from LexerCPP import LexerCPP
-            return LexerCPP(parent, 
-                Preferences.getEditor("CppCaseInsensitiveKeywords"))
-        elif language == "C#":
-            from LexerCSharp import LexerCSharp
-            return LexerCSharp(parent)
-        elif language == "IDL":
-            from LexerIDL import LexerIDL
-            return LexerIDL(parent)
-        elif language == "Java":
-            from LexerJava import LexerJava
-            return LexerJava(parent)
-        elif language == "JavaScript":
-            from LexerJavaScript import LexerJavaScript
-            return LexerJavaScript(parent)
-        elif language == "SQL":
-            from LexerSQL import LexerSQL
-            return LexerSQL(parent)
-        elif language == "HTML":
-            from LexerHTML import LexerHTML
-            return LexerHTML(parent)
-        elif language == "Perl":
-            from LexerPerl import LexerPerl
-            return LexerPerl(parent)
-        elif language == "Bash":
-            from LexerBash import LexerBash
-            return LexerBash(parent)
-        elif language == "Ruby":
-            from LexerRuby import LexerRuby
-            return LexerRuby(parent)
-        elif language == "Lua":
-            from LexerLua import LexerLua
-            return LexerLua(parent)
-        elif language == "CSS":
-            from LexerCSS import LexerCSS
-            return LexerCSS(parent)
-        elif language == "TeX":
-            from LexerTeX import LexerTeX
-            return LexerTeX(parent)
-        elif language == "Diff":
-            from LexerDiff import LexerDiff
-            return LexerDiff(parent)
-        elif language == "Makefile":
-            from LexerMakefile import LexerMakefile
-            return LexerMakefile(parent)
-        elif language == "Properties":
-            from LexerProperties import LexerProperties
-            return LexerProperties(parent)
-        elif language == "Batch":
-            from LexerBatch import LexerBatch
-            return LexerBatch(parent)
-        elif language == "D":
-            from LexerD import LexerD
-            return LexerD(parent)
-        elif language == "Povray":
-            from LexerPOV import LexerPOV
-            return LexerPOV(parent)
-        elif language == "CMake":
-            from LexerCMake import LexerCMake
-            return LexerCMake(parent)
-        elif language == "VHDL":
-            from LexerVHDL import LexerVHDL
-            return LexerVHDL(parent)
-        else:
-            return None
-    except ImportError:
-        return None
+    if not pyname:
+        try:
+            if language == "Python":
+                from LexerPython import LexerPython
+                return LexerPython(parent)
+            elif language == "C++":
+                from LexerCPP import LexerCPP
+                return LexerCPP(parent, 
+                    Preferences.getEditor("CppCaseInsensitiveKeywords"))
+            elif language == "C#":
+                from LexerCSharp import LexerCSharp
+                return LexerCSharp(parent)
+            elif language == "IDL":
+                from LexerIDL import LexerIDL
+                return LexerIDL(parent)
+            elif language == "Java":
+                from LexerJava import LexerJava
+                return LexerJava(parent)
+            elif language == "JavaScript":
+                from LexerJavaScript import LexerJavaScript
+                return LexerJavaScript(parent)
+            elif language == "SQL":
+                from LexerSQL import LexerSQL
+                return LexerSQL(parent)
+            elif language == "HTML":
+                from LexerHTML import LexerHTML
+                return LexerHTML(parent)
+            elif language == "Perl":
+                from LexerPerl import LexerPerl
+                return LexerPerl(parent)
+            elif language == "Bash":
+                from LexerBash import LexerBash
+                return LexerBash(parent)
+            elif language == "Ruby":
+                from LexerRuby import LexerRuby
+                return LexerRuby(parent)
+            elif language == "Lua":
+                from LexerLua import LexerLua
+                return LexerLua(parent)
+            elif language == "CSS":
+                from LexerCSS import LexerCSS
+                return LexerCSS(parent)
+            elif language == "TeX":
+                from LexerTeX import LexerTeX
+                return LexerTeX(parent)
+            elif language == "Diff":
+                from LexerDiff import LexerDiff
+                return LexerDiff(parent)
+            elif language == "Makefile":
+                from LexerMakefile import LexerMakefile
+                return LexerMakefile(parent)
+            elif language == "Properties":
+                from LexerProperties import LexerProperties
+                return LexerProperties(parent)
+            elif language == "Batch":
+                from LexerBatch import LexerBatch
+                return LexerBatch(parent)
+            elif language == "D":
+                from LexerD import LexerD
+                return LexerD(parent)
+            elif language == "Povray":
+                from LexerPOV import LexerPOV
+                return LexerPOV(parent)
+            elif language == "CMake":
+                from LexerCMake import LexerCMake
+                return LexerCMake(parent)
+            elif language == "VHDL":
+                from LexerVHDL import LexerVHDL
+                return LexerVHDL(parent)
+            elif language == "TCL":
+                from LexerTCL import LexerTCL
+                return LexerTCL(parent)
+            elif language == "Fortran":
+                from LexerFortran import LexerFortran
+                return LexerFortran(parent)
+            elif language == "Fortran77":
+                from LexerFortran77 import LexerFortran77
+                return LexerFortran77(parent)
+            elif language == "Pascal":
+                from LexerPascal import LexerPascal
+                return LexerPascal(parent)
+            elif language == "PostScript":
+                from LexerPostScript import LexerPostScript
+                return LexerPostScript(parent)
+            elif language == "XML":
+                from LexerXML import LexerXML
+                return LexerXML(parent)
+            elif language == "YAML":
+                from LexerYAML import LexerYAML
+                return LexerYAML(parent)
+            
+            elif language in LexerRegistry:
+                return LexerRegistry[language][2](parent)
+            
+            else:
+                return __getPygmentsLexer(parent)
+        except ImportError:
+            return __getPygmentsLexer(parent)
+    else:
+        return __getPygmentsLexer(parent, name = pyname)
 
+def __getPygmentsLexer(parent, name = ""):
+    """
+    Private module function to instantiate a pygments lexer.
+    
+    @param parent reference to the parent widget
+    @keyparam name name of the pygments lexer to use (string)
+    @return reference to the lexer (LexerPygments) or None
+    """
+    from LexerPygments import LexerPygments
+    lexer = LexerPygments(parent, name = name)
+    if lexer.canStyle():
+        return lexer
+    else:
+        return None
+    
 def getOpenFileFiltersList(includeAll = False, asString = False):
     """
     Module function to get the file filter list for an open file operation.
@@ -172,7 +280,7 @@ def getOpenFileFiltersList(includeAll = False, asString = False):
         << QApplication.translate('Lexers', 
             'PHP Files (*.php *.php3 *.php4 *.php5 *.phtml)') \
         << QApplication.translate('Lexers', 
-            'XML Files (*.xml *.xsl *.xslt *.dtd)') \
+            'XML Files (*.xml *.xsl *.xslt *.dtd *.svg *.xul *.xsd)') \
         << QApplication.translate('Lexers', 
             'Qt Resource Files (*.qrc)') \
         << QApplication.translate('Lexers', 
@@ -207,6 +315,25 @@ def getOpenFileFiltersList(includeAll = False, asString = False):
             'CMake Files (CMakeLists.txt *.cmake *.ctest)') \
         << QApplication.translate('Lexers', 
             'VHDL Files (*.vhd *.vhdl)')
+    
+    if QSCINTILLA_VERSION() >= 0x020201:
+        openFileFiltersList \
+            << QApplication.translate('Lexers', 
+                'TCL/Tk Files (*.tcl *.tk)') \
+            << QApplication.translate('Lexers', 
+                'Fortran Files (*.f90 *.f95 *.f2k)') \
+            << QApplication.translate('Lexers', 
+                'Fortran77 Files (*.f *.for)') \
+            << QApplication.translate('Lexers', 
+                'Pascal Files (*.dpr *.dpk *.pas *.dfm *.inc *.pp)') \
+            << QApplication.translate('Lexers', 
+                'PostScript Files (*.ps)') \
+            << QApplication.translate('Lexers', 
+                'YAML Files (*.yaml *.yml)')
+    
+    for name in LexerRegistry:
+        openFileFiltersList << LexerRegistry[name][3]
+    
     openFileFiltersList.sort()
     if includeAll:
         openFileFiltersList.append(QApplication.translate('Lexers', 'All Files (*)'))
@@ -227,86 +354,107 @@ def getSaveFileFiltersList(includeAll = False, asString = False):
     @return file filter list (QStringList or QString)
     """
     saveFileFiltersList = QStringList() \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Python Files (*.py)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Python Files win32 (*.pyw)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Pyrex Files (*.pyx)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Quixote Template Files (*.ptl)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Ruby Files (*.rb)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "IDL Files (*.idl)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "C Files (*.c)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "C++ Files (*.cpp)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "C++/C Header Files (*.h)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "C# Files (*.cs)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "HTML Files (*.html)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "PHP Files (*.php)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "ASP Files (*.asp)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "CSS Files (*.css)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "QSS Files (*.qss)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "XML Files (*.xml)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "XSL Files (*.xsl)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "DTD Files (*.dtd)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Qt Resource Files (*.qrc)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "D Files (*.d)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "D Interface Files (*.di)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Java Files (*.java)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "JavaScript Files (*.js)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "SQL Files (*.sql)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Docbook Files (*.docbook)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Perl Files (*.pl)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Perl Module Files (*.pm)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Lua Files (*.lua)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Shell Files (*.sh)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Batch Files (*.bat)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "TeX Files (*.tex)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "TeX Template Files (*.sty)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Diff Files (*.diff)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Make Files (*.mak)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Properties Files (*.ini)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             "Configuration Files (*.cfg)") \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             'Povray Files (*.pov)') \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             'CMake Files (CMakeLists.txt)') \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             'CMake Macro Files (*.cmake)') \
-        << QApplication.translate('ViewManager', 
+        << QApplication.translate('Lexers', 
             'VHDL Files (*.vhd)')
+    
+    if QSCINTILLA_VERSION() >= 0x020201:
+        saveFileFiltersList \
+            << QApplication.translate('Lexers', 
+                'TCL Files (*.tcl)') \
+            << QApplication.translate('Lexers', 
+                'Tk Files (*.tk)') \
+            << QApplication.translate('Lexers', 
+                'Fortran Files (*.f95)') \
+            << QApplication.translate('Lexers', 
+                'Fortran77 Files (*.f)') \
+            << QApplication.translate('Lexers', 
+                'Pascal Files (*.pas)') \
+            << QApplication.translate('Lexers', 
+                'PostScript Files (*.ps)') \
+            << QApplication.translate('Lexers', 
+                'YAML Files (*.yml)')
+    
+    for name in LexerRegistry:
+        saveFileFiltersList << LexerRegistry[name][4]
+    
     saveFileFiltersList.sort()
     
     if includeAll:
@@ -318,7 +466,7 @@ def getSaveFileFiltersList(includeAll = False, asString = False):
         return saveFileFiltersList
 
 def getDefaultLexerAssociations():
-    return {
+    assocs = {
         '*.sh'              : "Bash",
         '*.bash'            : "Bash",
         "*.bat"             : "Batch",
@@ -358,6 +506,7 @@ def getDefaultLexerAssociations():
         '*.xslt'            : "HTML",
         '*.dtd'             : "HTML",
         '*.rdf'             : "HTML",
+        '*.xul'             : "HTML", 
         '*.docbook'         : "HTML",
         '*.ui'              : "HTML",
         '*.ts'              : "HTML",
@@ -369,6 +518,7 @@ def getDefaultLexerAssociations():
         '*.e3t'             : "HTML",
         '*.e4d'             : "HTML",
         '*.e4k'             : "HTML",
+        '*.e4m'             : "HTML", 
         '*.e4p'             : "HTML",
         '*.e4q'             : "HTML",
         '*.e4s'             : "HTML",
@@ -407,3 +557,35 @@ def getDefaultLexerAssociations():
         '*.vhd'             : "VHDL", 
         '*.vhdl'            : "VHDL", 
     }
+    
+    if QSCINTILLA_VERSION() >= 0x020201:
+        assocs["*.tcl"]  = "TCL"
+        assocs["*.tk"]   = "TCL"
+        assocs["*.f"]    = "Fortran77"
+        assocs["*.for"]  = "Fortran77"
+        assocs["*.f90"]  = "Fortran"
+        assocs["*.f95"]  = "Fortran"
+        assocs["*.f2k"]  = "Fortran"
+        assocs["*.dpr"]  = "Pascal"
+        assocs["*.dpk"]  = "Pascal"
+        assocs["*.pas"]  = "Pascal"
+        assocs["*.dfm"]  = "Pascal"
+        assocs["*.inc"]  = "Pascal"
+        assocs["*.pp"]   = "Pascal"
+        assocs["*.ps"]   = "PostScript"
+        assocs["*.xml"]  = "XML"
+        assocs["*.xsl"]  = "XML"
+        assocs["*.svg"]  = "XML"
+        assocs["*.xsd"]  = "XML"
+        assocs["*.xslt"] = "XML"
+        assocs["*.dtd"]  = "XML"
+        assocs["*.rdf"]  = "XML"
+        assocs["*.xul"]  = "XML"
+        assocs["*.yaml"] = "YAML"
+        assocs["*.yml"]  = "YAML"
+    
+    for name in LexerRegistry:
+        for pattern in LexerRegistry[name][5]:
+            assocs[pattern] = name
+    
+    return assocs
