@@ -434,5 +434,8 @@ character except an alphabetic character.</td></tr>
         @param event reference to the key press event (QKeyEvent)
         """
         if event.key() == Qt.Key_Escape:
+            aw = self.viewmanager.activeWindow()
+            if aw:
+                aw.setFocus(Qt.ActiveWindowFocusReason)
             event.accept()
             self.close()
