@@ -503,10 +503,13 @@ class Shell(QsciScintillaCompat):
             self.__write(self.trUtf8('\nNot connected'))
         else:
             version = version.replace("#", unicode(self.trUtf8("No.")))
-            self.__write(self.trUtf8('%1 on %2, %3')
-                .arg(version)
-                .arg(platform)
-                .arg(dbgclient))
+            if platform != "" and dbgclient != "":
+                self.__write(self.trUtf8('%1 on %2, %3')
+                    .arg(version)
+                    .arg(platform)
+                    .arg(dbgclient))
+            else:
+                self.__write(version)
         self.__write('\n')
         
         self.__write(sys.ps1)
@@ -804,7 +807,6 @@ class Shell(QsciScintillaCompat):
                         self.delete()
                 elif indexFrom >= 0:
                     self.delete()
-                self.setSelection(lineTo, indexTo, lineTo, indexTo)
             else:
                 self.delete()
         
