@@ -8,6 +8,7 @@ Module implementing a simple terminal based on QScintilla.
 """
 
 import sys
+import os
 
 from PyQt4.QtCore import *
 from PyQt4.QtGui import *
@@ -801,10 +802,7 @@ class Terminal(QsciScintillaCompat):
         Public slot to clear the display.
         """
         QsciScintillaCompat.clear(self)
-        if sys.platform == "win32":
-            self.__send("\n")
-        else:
-            self.__send(self.__ctrl["u"] + "\n")
+        self.__send("\n")
         
     def __reset(self):
         """
@@ -822,12 +820,15 @@ class Terminal(QsciScintillaCompat):
             args.append("/Q")
             self.__process.start("cmd.exe", args)
         else:
-            if not Preferences.getTerminal("ReadRcFile"):
-                args.append("--norc")
-            args.append("-i")
-            self.__process.start("bash", args)
-
-            self.__send("""PS1="\u@\h:\w> "\n""")
+            shell = Preferences.getTerminal("Shell")
+            if shell.isEmpty():
+                shell = os.environ.get('SHELL')
+                if shell is None:
+                    self.__insertText(self.trUtf8("No shell has been configured."))
+                    return
+            if Preferences.getTerminal("ShellInteractive"):
+                args.append("-i")
+            self.__process.start(shell,  args)
         
     def __stopShell(self):
         """
