@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -20,6 +20,7 @@ from PyQt4.QtGui import *
 
 from KdeQt import KQMessageBox
 from KdeQt.KQProgressDialog import KQProgressDialog
+from KdeQt.KQApplication import e4App
 
 from TaskPropertiesDialog import TaskPropertiesDialog
 from TaskFilterConfigDialog import TaskFilterConfigDialog
@@ -348,7 +349,7 @@ class TaskViewer(QTreeWidget):
         self.setSortingEnabled(True)
         
         self.__headerItem = QTreeWidgetItem(QStringList() << "" << "" \
-            << self.trUtf8("Description") << self.trUtf8("Filename") \
+            << self.trUtf8("Summary") << self.trUtf8("Filename") \
             << self.trUtf8("Line") << "")
         self.__headerItem.setIcon(0, UI.PixmapCache.getIcon("taskCompleted.png"))
         self.__headerItem.setIcon(1, UI.PixmapCache.getIcon("taskPriority.png"))
@@ -394,6 +395,8 @@ class TaskViewer(QTreeWidget):
                               self.__configureFilter)
         self.__menu.addSeparator()
         self.__menu.addAction(self.trUtf8("Resi&ze columns"), self.__resizeColumns)
+        self.__menu.addSeparator()
+        self.__menu.addAction(self.trUtf8("Configure..."), self.__configure)
         
         self.__backMenu = QMenu(self)
         self.__backMenu.addAction(self.trUtf8("&New Task..."), self.__newTask)
@@ -418,6 +421,8 @@ class TaskViewer(QTreeWidget):
                               self.__configureFilter)
         self.__backMenu.addSeparator()
         self.__backMenu.addAction(self.trUtf8("Resi&ze columns"), self.__resizeColumns)
+        self.__backMenu.addSeparator()
+        self.__backMenu.addAction(self.trUtf8("Configure..."), self.__configure)
         
         self.setContextMenuPolicy(Qt.CustomContextMenu)
         self.connect(self, SIGNAL("customContextMenuRequested(const QPoint &)"),
@@ -808,3 +813,9 @@ class TaskViewer(QTreeWidget):
             count += 1
             
         progress.setValue(len(files))
+    
+    def __configure(self):
+        """
+        Private method to open the configuration dialog.
+        """
+        e4App().getObject("UserInterface").showPreferences("tasksPage")
