@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -28,6 +28,7 @@ BrowserItemClass      = 4
 BrowserItemMethod     = 5
 BrowserItemAttributes = 6
 BrowserItemAttribute  = 7
+BrowserItemCoding     = 8
 
 class BrowserModel(QAbstractItemModel):
     """
@@ -41,7 +42,7 @@ class BrowserModel(QAbstractItemModel):
         """
         QAbstractItemModel.__init__(self, parent)
         
-        rootData = QVariant(self.trUtf8("Name"))
+        rootData = QVariant(QApplication.translate("BrowserModel", "Name"))
         self.rootItem = BrowserItem(None, rootData)
         
         self.progDir = None
@@ -415,6 +416,9 @@ class BrowserModel(QAbstractItemModel):
                 self.beginInsertRows(self.createIndex(parentItem.row(), 0, parentItem),
                     0, len(keys) - 1)
             for key in keys:
+                if key.startswith("@@"):
+                    # special treatment done later
+                    continue
                 cl = dict[key]
                 try:
                     if cl.module == moduleName:
@@ -422,6 +426,16 @@ class BrowserModel(QAbstractItemModel):
                         self._addItem(node, parentItem)
                 except AttributeError:
                     pass
+            if "@@Coding@@" in keys:
+                node = BrowserCodingItem(parentItem, 
+                    QApplication.translate("BrowserModel", "Coding: %1")\
+                        .arg(dict["@@Coding@@"].coding))
+                self._addItem(node, parentItem)
+            if "@@Globals@@" in keys:
+                node = BrowserClassAttributesItem(parentItem, 
+                    dict["@@Globals@@"].globals, 
+                    QApplication.translate("BrowserModel", "Globals"))
+                self._addItem(node, parentItem)
             if repopulate:
                 self.endInsertRows()
 
@@ -460,7 +474,18 @@ class BrowserModel(QAbstractItemModel):
         
         if len(cl.attributes):
             node = BrowserClassAttributesItem(\
-                parentItem, cl.attributes, self.trUtf8("Attributes"))
+                parentItem, cl.attributes, 
+                QApplication.translate("BrowserModel", "Attributes"))
+            if repopulate:
+                self.addItem(node, 
+                    self.createIndex(parentItem.row(), 0, parentItem))
+            else:
+                self._addItem(node, parentItem)
+        
+        if len(cl.globals):
+            node = BrowserClassAttributesItem(\
+                parentItem, cl.globals, 
+                QApplication.translate("BrowserModel", "Attributes (global)"))
             if repopulate:
                 self.addItem(node, 
                     self.createIndex(parentItem.row(), 0, parentItem))
@@ -811,6 +836,8 @@ class BrowserFileItem(BrowserItem):
             self.icon = UI.PixmapCache.getIcon("fileResource.png")
         elif self.isProjectFile():
             self.icon = UI.PixmapCache.getIcon("fileProject.png")
+        elif self.isMultiProjectFile():
+            self.icon = UI.PixmapCache.getIcon("fileMultiProject.png")
         elif self.isIdlFile():
             self.icon = UI.PixmapCache.getIcon("fileIDL.png")
             self._populated = False
@@ -818,6 +845,8 @@ class BrowserFileItem(BrowserItem):
             self._moduleName = os.path.basename(finfo)
         elif self.isPixmapFile():
             self.icon = UI.PixmapCache.getIcon("filePixmap.png")
+        elif self.isSvgFile():
+            self.icon = UI.PixmapCache.getIcon("fileSvg.png")
         elif self.isDFile():
             self.icon = UI.PixmapCache.getIcon("fileD.png")
         else:
@@ -926,6 +955,14 @@ class BrowserFileItem(BrowserItem):
         """
         return self.fileext in ['.e3p', '.e3pz', '.e4p', '.e4pz']
     
+    def isMultiProjectFile(self):
+        """
+        Public method to check, if this file is an eric4 multi project file.
+        
+        @return flag indicating an eric4 project file (boolean)
+        """
+        return self.fileext in ['.e4m', '.e4mz']
+    
     def isIdlFile(self):
         """
         Public method to check, if this file is a CORBA IDL file.
@@ -944,6 +981,14 @@ class BrowserFileItem(BrowserItem):
                                 '.pnm', '.pbm', '.pgm', '.ppm', '.gif',
                                 '.mng']
     
+    def isSvgFile(self):
+        """
+        Public method to check, if this file is a SVG file.
+        
+        @return flag indicating a SVG file (boolean)
+        """
+        return self.fileext == '.svg'
+    
     def isDFile(self):
         """
         Public method to check, if this file is a D file.
@@ -1055,6 +1100,21 @@ class BrowserClassItem(BrowserItem):
         """
         return self._classObject
     
+    def lessThan(self, other, column, order):
+        """
+        Public method to check, if the item is less than the other one.
+        
+        @param other reference to item to compare against (BrowserItem)
+        @param column column number to use for the comparison (integer)
+        @param order sort order (Qt.SortOrder) (for special sorting)
+        @return true, if this item is less than other (boolean)
+        """
+        if issubclass(other.__class__, BrowserCodingItem) or \
+           issubclass(other.__class__, BrowserClassAttributesItem):
+            return order == Qt.DescendingOrder
+        
+        return BrowserItem.lessThan(self, other, column, order)
+    
     def isPublic(self):
         """
         Public method returning the public visibility status.
@@ -1128,6 +1188,8 @@ class BrowserMethodItem(BrowserItem):
                 return order == Qt.AscendingOrder
             if other.name.startswith('__init__'):
                 return order == Qt.DescendingOrder
+        elif issubclass(other.__class__, BrowserClassAttributesItem):
+            return order == Qt.DescendingOrder
         
         return BrowserItem.lessThan(self, other, column, order)
     
@@ -1166,10 +1228,27 @@ class BrowserClassAttributesItem(BrowserItem):
         @return reference to the list of attributes
         """
         return self._attributes
+    
+    def lessThan(self, other, column, order):
+        """
+        Public method to check, if the item is less than the other one.
+        
+        @param other reference to item to compare against (BrowserItem)
+        @param column column number to use for the comparison (integer)
+        @param order sort order (Qt.SortOrder) (for special sorting)
+        @return true, if this item is less than other (boolean)
+        """
+        if issubclass(other.__class__, BrowserCodingItem):
+            return order == Qt.DescendingOrder
+        elif issubclass(other.__class__, BrowserClassItem) or \
+             issubclass(other.__class__, BrowserMethodItem):
+            return order == Qt.AscendingOrder
+        
+        return BrowserItem.lessThan(self, other, column, order)
 
 class BrowserClassAttributeItem(BrowserItem):
     """
-    Class implementing the data structure for browser class items.
+    Class implementing the data structure for browser class attribute items.
     """
     def __init__(self, parent, attribute):
         """
@@ -1181,6 +1260,7 @@ class BrowserClassAttributeItem(BrowserItem):
         BrowserItem.__init__(self, parent, attribute.name)
         
         self.type_ = BrowserItemAttribute
+        self._attributeObject = attribute
         self.__public = attribute.isPublic()
         if attribute.isPrivate():
             self.icon = UI.PixmapCache.getIcon("attribute_private.png")
@@ -1196,3 +1276,50 @@ class BrowserClassAttributeItem(BrowserItem):
         @return flag indicating public visibility (boolean)
         """
         return self.__public
+    
+    def attributeObject(self):
+        """
+        Public method returning the class object.
+        
+        @return reference to the class object
+        """
+        return self._attributeObject
+    
+    def fileName(self):
+        """
+        Public method returning the filename.
+        
+        @return filename (string)
+        """
+        return self._attributeObject.file
+
+class BrowserCodingItem(BrowserItem):
+    """
+    Class implementing the data structure for browser coding items.
+    """
+    def __init__(self, parent, text):
+        """
+        Constructor
+        
+        @param parent parent item
+        @param text text to be shown by this item (QString)
+        """
+        BrowserItem.__init__(self, parent, text)
+        
+        self.type_ = BrowserItemCoding
+        self.icon = UI.PixmapCache.getIcon("textencoding.png")
+    
+    def lessThan(self, other, column, order):
+        """
+        Public method to check, if the item is less than the other one.
+        
+        @param other reference to item to compare against (BrowserItem)
+        @param column column number to use for the comparison (integer)
+        @param order sort order (Qt.SortOrder) (for special sorting)
+        @return true, if this item is less than other (boolean)
+        """
+        if issubclass(other.__class__, BrowserClassItem) or \
+           issubclass(other.__class__, BrowserClassAttributesItem):
+            return order == Qt.AscendingOrder
+        
+        return BrowserItem.lessThan(self, other, column, order)
