@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -17,7 +17,7 @@ class _ClbrBase(object):
         
         @param module name of the module containing this class
         @param name name of this class
-        @param file filename containing this class
+        @param file filename containing this object
         @param lineno linenumber of the class definition
         """
         self.module = module
@@ -35,13 +35,14 @@ class ClbrBase(_ClbrBase):
         
         @param module name of the module containing this class
         @param name name of this class
-        @param file filename containing this class
+        @param file filename containing this object
         @param lineno linenumber of the class definition
         """
         _ClbrBase.__init__(self, module, name, file, lineno)
         self.methods = {}
         self.attributes = {}
         self.classes = {}
+        self.globals = {}
         
     def _addmethod(self, name, function):
         """
@@ -54,7 +55,7 @@ class ClbrBase(_ClbrBase):
         
     def _getmethod(self, name):
         """
-        Protected metho to retrieve a method by name.
+        Protected method to retrieve a method by name.
         
         @param name name of the method (string)
         @return the named method or None
@@ -64,18 +65,39 @@ class ClbrBase(_ClbrBase):
         except KeyError:
             return None
         
+    def _addglobal(self, attr):
+        """
+        Protected method to add information about global variables.
+        
+        @param attr Attribute object to be added (Attribute)
+        """
+        if not self.globals.has_key(attr.name):
+            self.globals[attr.name] = attr
+        
+    def _getglobal(self, name):
+        """
+        Protected method to retrieve a global variable by name.
+        
+        @param name name of the global variable (string)
+        @return the named global variable or None
+        """
+        try:
+            return self.globals[name]
+        except KeyError:
+            return None
+        
     def _addattribute(self, attr):
         """
-        Protected metho to add information about attributes.
+        Protected method to add information about attributes.
         
-        @param attr Attribute object to be added (string)
+        @param attr Attribute object to be added (Attribute)
         """
         if not self.attributes.has_key(attr.name):
             self.attributes[attr.name] = attr
         
     def _getattribute(self, name):
         """
-        Protected metho to retrieve an attribute by name.
+        Protected method to retrieve an attribute by name.
         
         @param name name of the attribute (string)
         @return the named attribute or None
@@ -87,10 +109,10 @@ class ClbrBase(_ClbrBase):
         
     def _addclass(self, name, _class):
         """
-        Protected metho method to add a nested class to this class.
+        Protected method method to add a nested class to this class.
         
         @param name name of the class
-        @param _class Class object to be added
+        @param _class Class object to be added (Class)
         """
         self.classes[name] = _class
         
@@ -144,13 +166,16 @@ class Attribute(_ClbrBase):
     """
     Class to represent an attribute.
     """
-    def __init__(self, name):
+    def __init__(self, module, name, file, lineno):
         """
         Constructor
         
-        @param name name of this attribute
+        @param module name of the module containing this class
+        @param name name of this class
+        @param file filename containing this attribute
+        @param lineno linenumber of the class definition
         """
-        _ClbrBase.__init__(self, None, name, None, None)
+        _ClbrBase.__init__(self, module, name, file, lineno)
 
 class Class(ClbrBase):
     """
@@ -179,10 +204,10 @@ class Module(ClbrBase):
         """
         Constructor
         
-        @param module name of the module containing this class
-        @param name name of this class
-        @param file filename containing this class
-        @param lineno linenumber of the class definition
+        @param module name of the module containing this module
+        @param name name of this module
+        @param file filename containing this module
+        @param lineno linenumber of the module definition
         """
         ClbrBase.__init__(self, module, name, file, lineno)
 
@@ -203,3 +228,19 @@ class Function(ClbrBase):
         """
         ClbrBase.__init__(self, module, name, file, lineno)
         self.parameters = [e.strip() for e in signature.split(separator)]
+
+class Coding(ClbrBase):
+    """
+    Class to represent a source coding.
+    """
+    def __init__(self, module, file, lineno, coding):
+        """
+        Constructor
+        
+        @param module name of the module containing this module
+        @param file filename containing this module
+        @param lineno linenumber of the module definition
+        @param coding character coding of the source file
+        """
+        ClbrBase.__init__(self, module, "Coding", file, lineno)
+        self.coding = coding
