@@ -24,6 +24,8 @@ from PyQt4.QtCore import QRegExp, QString, QStringList, QDir, QProcess, Qt, \
 from PyQt4.QtGui import QApplication
 from PyQt4.Qsci import QSCINTILLA_VERSION_STR, QsciScintilla
 
+from Globals import isWindowsPlatform   # import this method into the Utilities namespace
+
 from KdeQt.KQApplication import e4App
 import KdeQt
 
@@ -922,10 +924,15 @@ def compile(file, codestring = ""):
             error = detail.msg
         return (1, fn, line, code, error)
     except ValueError, detail:
-        fn = detail.filename
-        line = detail.lineno
+        try:
+            fn = detail.filename
+            line = detail.lineno
+            error = detail.msg
+        except AttributeError:
+            fn = ""
+            line = 1
+            error = unicode(detail)
         code = ""
-        error = detail.msg
         return (1, fn, line, code, error)
     except StandardError, detail:
         try:
