@@ -280,10 +280,24 @@ class VcsProjectHelper(QObject):
         Protected slot used to import the local project into the repository.
         
         <b>NOTE</b>: 
-            This does not necvessarily make the local project a vcs controlled
+            This does not necessarily make the local project a vcs controlled
             project. You may have to checkout the project from the repository in 
             order to accomplish that.
         """
+        def revertChanges():
+            """
+            Local function do revert the changes made to the project object.
+            """
+            self.project.pdata["VCS"] = pdata_vcs[:]
+            self.project.pdata["VCSOPTIONS"] = copy.deepcopy(pdata_vcsoptions)
+            self.project.pdata["VCSOTHERDATA"] = copy.deepcopy(pdata_vcsother)
+            self.project.vcs = vcs
+            self.project.vcsProjectHelper = vcsHelper
+            self.project.vcsBasicHelper = vcs is None
+            self.initMenu(self.project.vcsMenu)
+            self.project.setDirty(True)
+            self.project.saveProject()
+        
         pdata_vcs = self.project.pdata["VCS"][:]
         pdata_vcsoptions = copy.deepcopy(self.project.pdata["VCSOPTIONS"])
         pdata_vcsother = copy.deepcopy(self.project.pdata["VCSOTHERDATA"])
@@ -337,14 +351,10 @@ class VcsProjectHelper(QObject):
                 else:
                     # revert the changes to the local project 
                     # because the project dir is not a VCS directory
-                    self.project.pdata["VCS"] = pdata_vcs[:]
-                    self.project.pdata["VCSOPTIONS"] = copy.deepcopy(pdata_vcsoptions)
-                    self.project.pdata["VCSOTHERDATA"] = copy.deepcopy(pdata_vcsother)
-                    self.project.vcs = vcs
-                    self.project.vcsProjectHelper = vcsHelper
-                    self.initMenu(self.project.vcsMenu)
-                    self.project.setDirty(True)
-                    self.project.saveProject()
+                    revertChanges()
+            else:
+                # revert the changes because user cancelled
+                revertChanges()
 
     def _vcsUpdate(self):
         """
