@@ -110,7 +110,8 @@ def main():
     except getopt.error:
         usage()
 
-    excludeDirs = ["CVS", ".svn", "_svn", ".ropeproject", "dist", "build", "doc", "docs"]
+    excludeDirs = ["CVS", ".svn", "_svn", ".ropeproject", "_ropeproject", 
+                   ".eric4project", "_eric4project", "dist", "build", "doc", "docs"]
     excludePatterns = []
     outputFileName = ""
     recursive = False
