@@ -23,6 +23,12 @@ if "--nokde" in sys.argv:
 else:
     sys.e4nokde = os.getenv("e4nokde") is not None and os.getenv("e4nokde") == "1"
 
+# make ThirdParty package available as a packages repository
+try:
+    import pygments
+except ImportError:
+    sys.path.insert(2, os.path.join(os.path.dirname(__file__), "ThirdParty", "Pygments"))
+
 from Utilities import Startup
 import Utilities
 
@@ -68,4 +74,4 @@ def main():
     sys.exit(res)
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
