@@ -1,22 +1,27 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Eric4 QRegExp
 
-This is the main Python script that performs the neccessary initialization
+This is the main Python script that performs the necessary initialization
 of the QRegExp wizard module and starts the Qt event loop. This is a standalone 
 version of the integrated QRegExp wizard.
 """
 
 import sys
+import os
 
+# disable the usage of KDE widgets, if requested
+sys.e4nokde = False
 if "--nokde" in sys.argv:
     del sys.argv[sys.argv.index("--nokde")]
-    os.environ["e4nokde"] = "1"
+    sys.e4nokde = True
+else:
+    sys.e4nokde = os.getenv("e4nokde") is not None and os.getenv("e4nokde") == "1"
 
 from Utilities import Startup
 
@@ -29,8 +34,8 @@ def createMainWidget(argv):
     @return reference to the main widget (QWidget)
     """
     from Plugins.WizardPlugins.QRegExpWizard.QRegExpWizardDialog import \
-        QRegExpWizardDialog
-    return QRegExpWizardDialog(fromEric = False)
+        QRegExpWizardWindow
+    return QRegExpWizardWindow()
 
 def main():
     """
@@ -50,4 +55,4 @@ def main():
     sys.exit(res)
 
 if __name__ == '__main__':
-    main()
+    main()
\ No newline at end of file
