@@ -1,22 +1,27 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
 Eric4 Unittest
 
-This is the main Python script that performs the neccessary initialization
+This is the main Python script that performs the necessary initialization
 of the unittest module and starts the Qt event loop. This is a standalone 
 version of the integrated unittest module.
 """
 
 import sys
+import os
 
+# disable the usage of KDE widgets, if requested
+sys.e4nokde = False
 if "--nokde" in sys.argv:
     del sys.argv[sys.argv.index("--nokde")]
-    os.environ["e4nokde"] = "1"
+    sys.e4nokde = True
+else:
+    sys.e4nokde = os.getenv("e4nokde") is not None and os.getenv("e4nokde") == "1"
 
 from Utilities import Startup
 
@@ -28,12 +33,12 @@ def createMainWidget(argv):
     @param argv list of commandline parameters (list of strings)
     @return reference to the main widget (QWidget)
     """
-    from PyUnit.UnittestDialog import UnittestDialog
+    from PyUnit.UnittestDialog import UnittestWindow
     try:
         fn = argv[1]
     except IndexError:
         fn = None
-    return UnittestDialog(fn)
+    return UnittestWindow(fn)
 
 def main():
     """
@@ -54,4 +59,4 @@ def main():
     sys.exit(res)
 
 if __name__ == '__main__':
-    main()
+    main()
\ No newline at end of file
