@@ -39,7 +39,10 @@ else:
     sys.e4nokde = os.getenv("e4nokde") is not None and os.getenv("e4nokde") == "1"
 
 # make ThirdParty package available as a packages repository
-sys.path.insert(2, os.path.join(os.path.dirname(__file__), "ThirdParty"))
+try:
+    import pygments
+except ImportError:
+    sys.path.insert(2, os.path.join(os.path.dirname(__file__), "ThirdParty", "Pygments"))
 
 from KdeQt.KQApplication import KQApplication
 
