@@ -1,6 +1,7 @@
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002-2008 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002-2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 # This is the uninstall script for eric4.
 
@@ -88,8 +89,9 @@ def uninstallEric():
     for name in ['ericExamplesDir', 'ericDocDir', 'ericDTDDir', 'ericCSSDir',
                  'ericIconDir', 'ericPixDir', 'ericDir', 'ericTemplatesDir',
                  'ericCodeTemplatesDir', 'ericOthersDir', 'ericStylesDir']:
-        if os.path.exists(name):
-            shutil.rmtree(getConfig(name), True)
+        dirpath = getConfig(name)
+        if os.path.exists(dirpath):
+            shutil.rmtree(dirpath, True)
     
     # Cleanup translations
     for name in glob.glob(os.path.join(getConfig('ericTranslationsDir'), 'eric4_*.qm')):
