@@ -25,10 +25,9 @@ modDir = None
 pyModDir = None
 platBinDir = None
 distDir = None
-qtDataDir = None
+apisDir = None
 doCleanup = True
 doCompile = True
-specialInstall = False
 cfg = {}
 progLanguages = ["Python", "Ruby"]
 
@@ -38,13 +37,18 @@ def usage(rcode = 2):
 
     @param rcode the return code passed back to the calling process.
     """
-    global progName, platBinDir, modDir, distDir
+    global progName, platBinDir, modDir, distDir, apisDir
 
     print
     print "Usage:"
-    print "    %s [-chxz] [-b dir] [-d dir] [-f file] [-i dir]" % (progName)
+    print "    %s [-chxz] [-a dir] [-b dir] [-d dir] [-f file] [-i dir]" % (progName)
     print "where:"
     print "    -h        display this help message"
+    print "    -a dir    where the API files will be installed"
+    if apisDir:
+        print "              (default: %s)" % (apisDir)
+    else:
+        print "              (no default value)"
     print "    -b dir    where the binaries will be installed"
     print "              (default: %s)" % (platBinDir)
     print "    -d dir    where eric4 python files will be installed"
@@ -61,7 +65,7 @@ def usage(rcode = 2):
     print "dictionary called 'cfg' with the keys 'ericDir', 'ericPixDir', 'ericIconDir',"
     print "'ericDTDDir', 'ericCSSDir', 'ericStylesDir', 'ericDocDir', 'ericExamplesDir',"
     print "'ericTranslationsDir', 'ericTemplatesDir', 'ericCodeTemplatesDir',"
-    print "'ericOthersDir','bindir' and 'mdir'."
+    print "'ericOthersDir','bindir', 'mdir' and 'apidir."
     print "These define the directories for the installation of the various parts of"\
           " eric4."
 
@@ -72,15 +76,27 @@ def initGlobals():
     """
     Sets the values of globals that need more than a simple assignment.
     """
-    global platBinDir, modDir, pyModDir
+    global platBinDir, modDir, pyModDir, apisDir
 
     if sys.platform == "win32":
         platBinDir = sys.exec_prefix
+        if platBinDir.endswith("\\"):
+            platBinDir = platBinDir[:-1]
     else:
         platBinDir = "/usr/local/bin"
 
     modDir = distutils.sysconfig.get_python_lib(True)
     pyModDir = modDir
+    
+    try:
+        from PyQt4 import pyqtconfig
+        qtDataDir = pyqtconfig._pkg_config["qt_data_dir"]
+    except (AttributeError, ImportError):
+        qtDataDir = None
+    if qtDataDir:
+        apisDir = os.path.join(qtDataDir, "qsci", "api")
+    else:
+        apisDir = None
 
 
 def copyToFile(name, text):
@@ -203,36 +219,6 @@ Package containing the global plugins.
         f.close()
 
 
-def getAPIsPath(progLanguage = None):
-    """
-    Get the name of the directory containing the API files.
-    
-    @param progLanguage programming language of the API files (string)
-    @return name of the directory containing the API files (string)
-    """
-    global cfg, qtDataDir
-    
-    if not specialInstall and qtDataDir is None:
-        try:
-            from PyQt4 import pyqtconfig
-            qtDataDir = pyqtconfig._pkg_config["qt_data_dir"]
-        except (AttributeError, ImportError):
-            print
-            print "Please enter the name of the Qt data directory."
-            print "(That is the one containing the 'qsci' subdirectory.)"
-            qtDataDir = raw_input(">>> ")
-    if qtDataDir:
-        scidir = os.path.join(qtDataDir, "qsci")
-        if progLanguage is None:
-            apidir = os.path.join(scidir, "api")
-        else:
-            apidir = os.path.join(scidir, "api", progLanguage.lower())
-    else:
-        apidir = cfg['ericOthersDir']
-    
-    return apidir
-
-
 def cleanUp():
     """
     Uninstall the old eric files.
@@ -400,24 +386,21 @@ def installEric():
     
     # install the API file
     for progLanguage in progLanguages:
-        apidir = getAPIsPath(progLanguage)
+        apidir = os.path.join(cfg['apidir'], progLanguage.lower())
         if not os.path.exists(apidir):
             os.makedirs(apidir)
         for apiName in glob.glob(os.path.join("eric", "APIs", progLanguage, "*.api")):
             try:
                 shutil.copy(apiName, apidir)
             except:
-                try:
-                    shutil.copy(apiName, cfg['ericOthersDir'])
-                except:
-                    print "Could not install '%s'." % apiName
+                print "Could not install '%s'." % apiName
 
 
 def createInstallConfig():
     """
     Create the installation config dictionary.
     """
-    global modDir, platBinDir, cfg
+    global modDir, platBinDir, cfg, apisDir
         
     ericdir = os.path.join(modDir, "eric4")
     cfg = {
@@ -436,7 +419,11 @@ def createInstallConfig():
         'bindir'               : platBinDir,
         'mdir'                 : modDir,
     }
-configLength = 14
+    if apisDir:
+        cfg['apidir'] = apisDir
+    else:
+        cfg['apidir'] = os.path.join(ericdir, "api")
+configLength = 15
     
 def createConfig():
     """
@@ -494,7 +481,7 @@ def getConfig(name):
        cfg['ericTemplatesDir'],
        cfg['ericCodeTemplatesDir'], cfg['ericOthersDir'],
        cfg['bindir'], cfg['mdir'], 
-       getAPIsPath(), apis)
+       cfg['apidir'], apis)
     copyToFile(fn, config)
 
 def doDependancyChecks():    
@@ -502,9 +489,12 @@ def doDependancyChecks():
     Perform some dependancy checks.
     """
     # perform dependency checks
-    if sys.version_info < (2,4,0):
+    if sys.version_info < (2, 4, 0):
         print 'Sorry, you must have Python 2.4.0 or higher.'
         sys.exit(5)
+    if sys.version_info > (2, 9, 9):
+        print 'Sorry, eric4 requires Python 2 for running.'
+        sys.exit(5)
     
     try:
         from PyQt4.QtCore import qVersion, PYQT_VERSION
@@ -569,16 +559,16 @@ def main(argv):
     import getopt
 
     # Parse the command line.
-    global progName, modDir, doCleanup, doCompile, distDir, cfg, specialInstall
+    global progName, modDir, doCleanup, doCompile, distDir, cfg, apisDir
     progName = os.path.basename(argv[0])
 
     initGlobals()
 
     try:
         if sys.platform == "win32":
-            optlist, args = getopt.getopt(argv[1:],"chxzb:d:f:")
+            optlist, args = getopt.getopt(argv[1:],"chxza:b:d:f:")
         else:
-            optlist, args = getopt.getopt(argv[1:],"chxzb:d:f:i:")
+            optlist, args = getopt.getopt(argv[1:],"chxza:b:d:f:i:")
     except getopt.GetoptError:
         usage()
 
@@ -589,11 +579,12 @@ def main(argv):
     for opt, arg in optlist:
         if opt == "-h":
             usage(0)
+        elif opt == "-a":
+            apisDir = arg
         elif opt == "-b":
             platBinDir = arg
         elif opt == "-d":
             modDir = arg
-            specialInstall = True
         elif opt == "-i":
             distDir = os.path.normpath(arg)
         elif opt == "-x":
