@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003-2005 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003-2009 Detlev Offenbach <detlev@die-offenbachs.de>
 #
-# This is a  script to patch Mod_python for eric3. 
+# This is a  script to patch mod_python for eric4. 
 
 """
-Script to patch mod_python for usage with the eric3 IDE.
+Script to patch mod_python for usage with the eric4 IDE.
 """
 
 import sys
@@ -30,10 +30,11 @@ def usage(rcode = 2):
     print "    %s [-h] [-d dir]" % (progName)
     print "where:"
     print "    -h             display this help message"
-    print "    -d dir         where Mod_python files are installed [default %s]" % (modDir)
+    print "    -d dir         where Mod_python files are installed [default %s]" % \
+        (modDir)
     print
     print "This script patches the file apache.py of the Mod_python distribution"
-    print "so that it will work with the eric3 debugger instead of pdb."
+    print "so that it will work with the eric4 debugger instead of pdb."
     print "Please see mod_python.html for more details."
     print
 
@@ -46,7 +47,7 @@ def initGlobals():
     """
     global modDir
 
-    modDir = os.path.join(distutils.sysconfig.get_python_lib(), "mod_python")
+    modDir = os.path.join(distutils.sysconfig.get_python_lib(True), "mod_python")
 
 def main(argv):
     """The main function of the script.
@@ -72,45 +73,46 @@ def main(argv):
         elif opt == "-d":
             global modDir
             modDir = arg
-            
+    
     try:
-        f = open(os.path.join(modDir, "apache.py"), "r")
+        filename = os.path.join(modDir, "apache.py")
+        f = open(filename, "r")
     except:
-        print "The file %s does not exist. Aborting."
+        print "The file %s does not exist. Aborting." % filename
         sys.exit(1)
-        
+    
     lines = f.readlines()
     f.close()
     
-    pdbFound = 0
-    ericFound = 0
+    pdbFound = False
+    ericFound = False
     
     sn = "apache.py"
     s = open(sn, "w")
     for line in lines:
         if not pdbFound and line.startswith("import pdb"):
-            s.write("import eric3.DebugClients.Python.eric3dbgstub as pdb\n")
-            pdbFound = 1
+            s.write("import eric4.DebugClients.Python.eric4dbgstub as pdb\n")
+            pdbFound = True
         else:
             s.write(line)
-            if line.startswith("import eric3"):
-                ericFound = 1
-                
+            if line.startswith("import eric4"):
+                ericFound = True
+    
     if not ericFound:
         s.write("\n")
         s.write('def initDebugger(name):\n')
         s.write('    """\n')
         s.write('    Initialize the debugger and set the script name to be reported \n')
-        s.write('    by the debugger. This is a patch for eric3.\n')
+        s.write('    by the debugger. This is a patch for eric4.\n')
         s.write('    """\n')
-        s.write('    if not pdb.initDebugger("noqt"):\n')
+        s.write('    if not pdb.initDebugger("standard"):\n')
         s.write('        raise ImportError("Could not initialize debugger")\n')
         s.write('    pdb.setScriptname(name)\n')
         s.write("\n")
     s.close()
     
     if ericFound:
-        print "Mod_python is already patched for eric3."
+        print "Mod_python is already patched for eric4."
         os.remove(sn)
     else:
         try:
@@ -120,7 +122,12 @@ def main(argv):
             print e
             os.remove(sn)
             sys.exit(1)
-            
+        except SyntaxError, e:
+            print "Error compiling %s. Aborting" % sn
+            print e
+            os.remove(sn)
+            sys.exit(1)
+        
         shutil.copy(os.path.join(modDir, "apache.py"),
                     os.path.join(modDir, "apache.py.orig"))
         shutil.copy(sn, modDir)
